#delimit;
clear;
set mem 50m;
capture log close;
capture program drop _all;
set logtype text;
set more off;


/*CHANGE THIS LINE TO REFLECT LOCAL DIRECTORY STRUCTURE*/
global REPDIR "C:\Users\ecascardi\Desktop\Data revised";


do "$REPDIR\Replication_WLCA\do_files\directory_location";


*---------------------------------------------------------------------------------------------------;
*** 	This do-file is called "data_construct.do".  
***	This was created on February 6, 2006 by John Bellows. 
***	Updated on 21 Nov, 2006
***	Updated on 12 October 2007 by Alex Rothenberg	
***	Updated again 6 November 2007 by John
***
***	Its purpose is to create the multiple data sets used in "War and Collective Action"
***
***	Data sources:
***	1) IRCBP 2005 Public Services Baseline Household Level Data
***	2) IRCBP 2007 Public Services Survey
***	**) Put the 2005 and 2007 surveys together
***	3) GoBifo 2005 Household Level Data
***	4) GoBifo 1990 Retrospective Roster Data
***	5) Chiefdom Level Data;
***		a) IRCBP data;
***		b) 2004 SLIHS hh;
***		c) 2004 SLIHS indiv;
***		d) 1989 HH survey;
***		e) GIS data
***		f) NGO data
***		g) Population data
***		h) NPWJ data
***		i) School data
***
***			For each dataset that goes in the chiefdom data, we will go through the following steps
***				i) data set specific fixes
***				ii) create chiefdom-level data by collapsing 
***				iii) merge in the chiefdom identifiers (the 2004 Census identifiers will be used throughout)
***				iv) do some re-naming and labeling
***				v) then save as "$SL_data/~_c.dta"
***
***	In the corresponding do-file "cp_data_construct_2" we do some more data-sets, then put everything together;
*-----------------------------------------------------------------------------------------------------;

*** Call the program that identifies the macros;
	do "$REPDIR\Replication_WLCA\do_files\directory_location";
	

*-------------------------------------------------------------------------------------------------------;
* 1) IRCBP 2005 Public Services Survey;
*-------------------------------------------------------------------------------------------------------;

	/* Use the publishable data, which has already cleaned and labeled everything */;
		use "$raw\nps-2005_clean", clear;

	/* In this data set, chief_2004census = ch_code, but need to make it a string for later merges*/;
		gen ch_code = string(chief_2004census, "%15.0g");
	
	/* Need to merge the Town data into the appropriate chiefdoms (analysis later at chiefdom level, not LC level) */;
		replace ch_code = "2102" if ch_code == "2191" ;  /* Makeni Town in Bombali Shebora Chiefdom*/;
		replace ch_code = "3108" if ch_code == "3191" ;  /* Bo Town in Kakua Chiefdom */;
		replace ch_code = "1212" if ch_code == "1291" ;  /* Kenema Town in Nongowa Chiefdom */;
		replace ch_code = "1304" if ch_code == "1391" ;  /* Koidu Town in Gbense Chiefom*/;
		replace ch_code = "3209" if ch_code == "3291" ;  /* Bonthe Town in Sittia Chiefdom*/;

	*---------------------------------------------------;
	*** Do some construction of variables;
	*---------------------------------------------------;

	/* HOUSEHOLD CONFLICT INDEX */;

		* (NB: Use only the questions that refer specifically to the household, NOT the community);

		rename c51 kill_com; rename c52 maim_com; rename c54 kill_hh;
		rename c55 maim_hh;  rename c56 refugee_hh; 

		egen i_c_index = rsum(kill_hh maim_hh refugee_hh);
			replace i_c_index = i_c_index/3;
			replace i_c_index = . if kill_hh == .;
			label var i_c_index "Conflict Index, simple average of 3 (incl refugee) IRCBP measures";

	/* CHIEFDOM AND VILLAGE CONFLICT INDEX */;

		bys ch_code: egen ch_c_index_temp = mean(i_c_index);
		bys ch_code: gen n = _N;
		gen n2 = n -1;
		gen ch_c_index = (ch_c_index_temp - i_c_index/n)*(n/n2);
		drop n n2 ch_c_index_temp;
		label var ch_c_index "Chiefdom ave of c_index, excluding individual";

		bys ea_code: egen v_c_index_temp = mean(i_c_index);
		bys ea_code: gen n = _N;
		gen n2 = n -1;
		gen v_c_index = (v_c_index_temp - i_c_index/n)*(n/n2);
		drop n n2 v_c_index_temp;
		label var v_c_index "EA ave of c_index, excluding individual";
		

	/* INSTITUTIONS AND POLITICS */;

		* Voting;	
			gen rvote_all = (d15 == 1 | d16 == 1);
			replace rvote_all = . if d15 == . & d16 == .;
			label var rvote_all "Registered to Vote in Any election, IRCBP";
			
		* Community meeting variables;	
			gen mtg_attend_any = (f1 == 1 | f3 == 1 | f4 == 1);
			replace mtg_attend_any = . if f1 == . & f3 == . & f4 == .;

		* School and Political Group;
			rename g23 g_school; 
			rename g24 g_political; 

		* Credit Group;
			rename g21 g_credit;
		* Social Groups;
			rename g17 g_women;
			rename g18 g_youth;
			rename g19 g_farmer;
			gen g_social = g_women == 1 | g_youth == 1 | g_farmer == 1;

		/* TRUST AND CHURCH */;

		* Church Group;
			rename g20 g_church;

		* Trust community members and outsiders;
			* OLD construction of trust variables;
				* for var g12 g13 : replace X = . if X==88;
				* for var g12 g13: replace X = 6-X;
				* gen t_comm = g12/5;
				* gen t_outsider = g13/5;

			* New construction to make it a binary, not an index variable;
				recode g12 (1 2 = 1) (3 4 5 = 0) (88 = .), gen(t_comm);
				recode g13 (1 2 = 1) (3 4 5 = 0) (88 = .), gen(t_outsider);
			
	/* SOCIO-ECONOMIC OUTCOMES */;

		gen cash = (b12 == 1);  
		gen radio = (b22 < 3 | b23 < 3); 
		gen stove = (b20 == 1);
		gen car_cycle = (b27 == 1 | b28 == 1); 
			
	/* DEMOGRAPHICS */;

		* Female;
			gen female = a3 == 2; 

		* Create de-meaned age;
			gen age = a4;
			egen age_m = mean(age);
			gen age_dm = age - age_m;	
	
		* Education;
			generate educ_any = .;
			label variable educ_any "education dummy";
       			replace educ_any = (b13 > 1 & b13 < .);

		* Traditional Authority Household;
			gen trad_leader = (b1 == 1 | b2 == 1 | b3 == 1);
			gen comm_leader = (b9 == 1 | b10 == 1| b4 == 1 | b6 == 1 | b7 == 1);
	
	/* INTERACTION TERMS */;
		foreach var in female age_dm educ_any trad_leader{;
			gen i_c_index_`var' = i_c_index*`var';
		};

	*---------------------------------------------------;
	*** Save this data for merging into chiefdom later;
	*---------------------------------------------------;
		sort ea_code hh_no;
		save "$temp\ps-2005_hh", replace;

	*---------------------------------------------------;
	*** Create the sample to be used in the analysis;
	*---------------------------------------------------;
	
		* Drop Freetown;
			drop if district== 42;

		* Only keep if no missing obs;
		gen miss = 0;
			foreach var of varlist 	kill_hh maim_hh refugee_hh							
							rvote_all mtg_attend_any
							g_school
							g_political g_church
							female educ_any age 
							trad_leader comm_leader radio cash{;
					replace miss = 1 if `var' == .;
				};
		keep if miss == 0;

		* Order, Keep, Sort, Save;
		order chief_2004census district ch_code ea_code hh_no kill_hh maim_hh refugee_hh i_c_index
						female age age_dm educ_any 
						rvote_all mtg_attend_any g_*
						t_comm t_outsider
						comm_leader trad_leader
						radio stove cash
						i_c_index_* v_c_index ch_c_index;
		keep chief_2004census district ch_code ea_code hh_no kill_hh maim_hh refugee_hh i_c_index
						female age age_dm educ_any 
						rvote_all mtg_attend_any g_*
						t_comm t_outsider
						comm_leader trad_leader
						radio stove cash
						i_c_index_* v_c_index ch_c_index;
		gen year = 2005;

		sort ea_code hh_no;
		save "$data/cp_nps-2005_analysis", replace;


*-------------------------------------------------------------------------------------------------------;
* 2) IRCBP 2007 Public Services Survey;
*-------------------------------------------------------------------------------------------------------;

	/* Use the cleaned data */;
		use "$raw/nps-2007_hh_clean.dta", clear;

	/* In this data set, chief_2004census = ch_code, but need to make it a string for later merges*/;
		gen ch_code = string(chief_2004census, "%15.0g");
	
	/* Need to merge the Town data into the appropriate chiefdoms (analysis later at chiefdom level, not LC level) */;
		replace ch_code = "2102" if ch_code == "2191" ;  /* Makeni Town in Bombali Shebora Chiefdom*/;
		replace ch_code = "3108" if ch_code == "3191" ;  /* Bo Town in Kakua Chiefdom */;
		replace ch_code = "1212" if ch_code == "1291" ;  /* Kenema Town in Nongowa Chiefdom */;
		replace ch_code = "1304" if ch_code == "1391" ;  /* Koidu Town in Gbense Chiefom*/;
		replace ch_code = "3209" if ch_code == "3291" ;  /* Bonthe Town in Sittia Chiefdom*/;

	*---------------------------------------------------;
	*** Do some construction of variables;
	*---------------------------------------------------;

	/* HOUSEHOLD CONFLICT INDEX */;

		* (NB: Use only the questions that refer specifically to the household, NOT the community);

		rename f5 kill_hh;  rename f4 maim_hh;  rename f8 refugee_hh;
		rename f6 burned_hh;  rename f7 fleecom_hh;  rename f9 ddr_hh; 

		egen i_c_index = rowtotal(kill_hh maim_hh refugee_hh);
			replace i_c_index = i_c_index/3;
			replace i_c_index = . if kill_hh == .;
			label var i_c_index "Conflict Index for 1990 Household, simple average of 3 (incl refugee) IRCBP measures";

	/* CHIEFDOM AND VILLAGE CONFLICT INDEX */;

		bys ch_code: egen ch_c_index_temp = mean(i_c_index);
		bys ch_code: gen n = _N;
		gen n2 = n -1;
		gen ch_c_index = (ch_c_index_temp - i_c_index/n)*(n/n2);
		drop n n2 ch_c_index_temp;
		label var ch_c_index "Chiefdom ave of c_index, excluding individual";

		bys ea_code: egen v_c_index_temp = mean(i_c_index);
		bys ea_code: gen n = _N;
		gen n2 = n -1;
		gen v_c_index = (v_c_index_temp - i_c_index/n)*(n/n2);
		drop n n2 v_c_index_temp;
		label var v_c_index "EA ave of c_index, excluding individual";
		

	/* INSTITUTIONS AND POLITICS */;

		* Voting;	
			gen rvote_all = g28;			/* NOTE: if don't know, then put "NO" not registered */;
			replace rvote_all = 0 if g28 == .;
			label var rvote_all "Planning to Vote in 2007 Election, IRCBP";
			
		* Community meeting variables;	
			gen mtg_attend_any = c15a;
			gen mtg_attend_comment = (c15a == 1 & c15b == 1);
			replace mtg_attend_comment = . if c15a == . & c15b == .;

		* School and Political Group;
			rename c7a g_school;
			rename c8a g_political; 
			gen g_sch_active = (g_school == 1 & c7b == 1);  replace g_sch_active = . if (g_school == . | c7b == .);
			gen g_pol_active = (g_political == 1 & c8b == 1);  replace g_pol_active = . if (g_political == . | c8b == .);

		* Credit Group and Social Group;
			rename c5a g_credit;
			rename c2a g_youth;
			rename c1a g_women;
			rename c3a g_farmer;
			gen g_social = g_women == 1 | g_youth == 1 | g_farmer == 1;
						
	/* TRUST AND CHURCH */;

		* Church Group;
			rename c4a g_church;
			gen g_ch_active = (g_church == 1 & c4b == 1);  replace g_ch_active = . if (g_church == . | c4b == .);
			
		* Trust community members and outsiders;
			gen t_comm = (c16a < 2);
				replace t_comm = . if c16a == 9;
			gen t_outsider = (c16b < 2);
				replace t_outsider = . if c16b == 9;
			
	/* SOCIO-ECONOMIC OUTCOMES */;

		gen cash = (b11 == 1 | b12 == 1);  
		gen radio = (a10h == 1); 
		gen car_cycle = (a10d == 1); 
		gen roof_tin = a23 == 3;
		gen phone = (a10b == 1);
			
	/* DEMOGRAPHICS */;

		* Female;
			gen female = (a2 == 2); 

		* Create de-meaned age;
			gen age = a3;
			egen age_m = mean(age);
			gen age_dm = age - age_m;	
	
		* Education;		
		/* ASK ALEX: WHY IS HE USING b4 INSTEAD OF a4? */;
			generate educ_any = .;  
			label variable educ_any "education dummy";
       			replace educ_any = (a4 > 0 & a4 < .);

		* Traditional Authority Household;
			gen trad_leader = (a32a == 1 | a32c == 1);
			gen comm_leader = (a32b == 1 | a32d == 1 | a32e == 1 | a32h == 1 | a32i == 1);

	/* VARIABLES IN GOBIFO NOW IN 2007 SURVEY */		
	
		* Road Brushing;
			gen road_brush = (c13 == 1);
	
		* Knowledge of Local Councilors, Chiefs;
			gen name_lc = (g8 == 1);
			gen name_chief = (g2 == 1); 
			gen election_date = (g26 == 1);
				
		* Ruling Family;
			gen chief_family = (a31 == 1);
			
	/* PRE-WAR LEADERSHIP VARIABLES */;

		* Pre-war district;
			rename f1 district_90;
	
		* Pre-war education (any);
			gen head_educ_any_90 = .;
			label var head_educ_any_90 "HH head in 1990 education";
			replace head_educ_any_90 = (f2>0 & f2!=.);			/* NB: count Koranic as educ */;

		* Pre-war trad leader;
			gen hh_trad_leader_90 = (f3a == 1 | f3b == 1);
			gen hh_comm_leader_90 = (f3c == 1 | f3d == 1 | f3f == 1 | f3g == 1);
			
	/* INTERACTION TERMS */;
		foreach var in female age_dm educ_any trad_leader {;
			gen i_c_index_`var' = i_c_index * `var';
		};

	/* Migration */;
		gen ch_today = chief_2004census;
			replace ch_today = 4200 if inlist(ch_today,4201,4202,4203,4204,4205,4206,4207,4208);
			replace ch_today = 4100 if inlist(ch_today,4101,4102,4103,4104);
		gen ch_1990 = district_90;
			replace ch_1990 = . if ch_1990 < 100 | ch_1990 ==5104;
		gen migrate = ch_today != ch_1990;
			replace migrate = . if ch_1990 == .;

	*---------------------------------------------------;
	*** Save this data for merging into chiefdom later;
	*---------------------------------------------------;
		sort ea_code hh_no;
		save "$temp/ps-2007_hh", replace;
		
	*---------------------------------------------------;
	*** Create the sample to be used in the analysis;
	*---------------------------------------------------;
	
		* Drop Freetown;
			drop if district == 42;

		* Only keep if no missing obs;
		/* NOTE: For the moment, care about the variables that are constant across surveys */;
			gen miss = 0;
			foreach var of varlist 	kill_hh maim_hh refugee_hh							
							rvote_all mtg_attend_any
							g_school
							g_political g_church
							female educ_any age age_dm 
							trad_leader comm_leader radio cash{;
					replace miss = 1 if `var' == .;
				};
			keep if miss == 0;

		* Order, Keep, Sort, Save;
			order district chief_2004census ea_code hh_no ch_code z7
					female educ_any age age_dm 
					kill_hh maim_hh refugee_hh i_c_index
					rvote_all mtg_attend_any  
					g_*
					t_comm t_outsider 
					trad_leader comm_leader 
					radio cash car_cycle roof_tin phone
					chief_family
					burned_hh fleecom_hh ddr_hh 
					road_brush name_chief name_lc election_date
					mtg_attend_comment g_sch_active g_pol_active g_ch_active
					ch_today ch_1990 migrate
					district_90 head_educ_any_90 hh_trad_leader_90 hh_comm_leader_90
					i_c_index_* v_c_index ch_c_index;
			keep district chief_2004census ea_code hh_no ch_code z7
					female educ_any age age_dm 
					kill_hh maim_hh refugee_hh i_c_index
					rvote_all mtg_attend_any  
					g_*
					t_comm t_outsider 
					trad_leader comm_leader 
					radio cash car_cycle roof_tin phone
					chief_family
					burned_hh fleecom_hh ddr_hh 
					road_brush name_chief name_lc election_date
					mtg_attend_comment g_sch_active g_pol_active g_ch_active
					ch_today ch_1990 migrate
					district_90 head_educ_any_90 hh_trad_leader_90 hh_comm_leader_90
					i_c_index_* v_c_index ch_c_index;

		gen year = 2007;

		sort ea_code hh_no;
		save "$data/cp_nps-2007_analysis", replace;

*-------------------------------------------------------------------------------------------------------;
* ***) Append the 2005 and 2007 data together;
*	NB: We have decided to treat the two surveys as repeated cross-sections
*		So, instead of merging we are going to append the two datasets
*-------------------------------------------------------------------------------------------------------;

	*---------------------------------------------------;
	*** Append 2005 data with 2007 data	;
	*---------------------------------------------------;
		use "$data/cp_nps-2005_analysis", clear;
		append using "$data/cp_nps-2007_analysis";

		* Want to absorb by ea/year (not just ea), so need to create ea/year id;
			bys ea_code year: gen f = _n == 1;
			gen ea_year = sum(f);

		save "$data/cp_nps-0507_append_analysis", replace;		

*-------------------------------------------------------------------------------------------------------;
* 3) GoBifo Household Data;
*-------------------------------------------------------------------------------------------------------;

	*** Use the cleaned (published) data;
		use "$raw/gbf-2005_hh.dta", clear;

	*---------------------------------------------------;
	*** Do some construction of variables;
	*---------------------------------------------------;

	/* HH CONFLICT INDEX */;
		for var s2aq1 s2aq2 s2aq3 s2aq4 s2aq5 s2aq7: replace X = . if X == 9;
		for var s2aq1 s2aq2 s2aq3 s2aq4 s2aq5 s2aq7: replace X = 0 if X == 2;

		rename s2aq1 maim_hh; rename s2aq2 kill_hh; rename s2aq3 child_cap;  rename s2aq4 women_cap;
		rename s2aq5 house_burn; rename s2aq7 flee_hh;	

		* NOTE: I changed this to be comparable to the conflict indexes in other years;
		egen i_c_index = rsum(maim_hh kill_hh flee_hh child_cap women_cap house_burn);
			replace i_c_index = i_c_index/6;
			replace i_c_index = . if maim_hh == .;
			label var i_c_index "Conflict Index, simple average of 3 (incl refugee) GBF measures";

	/* CHIEFDOM AND VILLAGE CONFLICT INDEX */;

		bys id_chief: egen ch_c_index_temp = mean(i_c_index);
		bys id_chief: gen n = _N;
		gen n2 = n -1;
		gen ch_c_index = (ch_c_index_temp - i_c_index/n)*(n/n2);
		drop n n2 ch_c_index_temp;
		label var ch_c_index "Chiefdom ave of c_index, excluding individual";

		bys id_vill: egen v_c_index_temp = mean(i_c_index);
		bys id_vill: gen n = _N;
		gen n2 = n -1;
		gen v_c_index = (v_c_index_temp - i_c_index/n)*(n/n2);
		drop n n2 v_c_index_temp;
		label var v_c_index "Village ave of c_index, excluding individual";

	/* INSTITUTIONS AND POLITICS */;

		* Voting;
		for var s8q6 s8q7: replace X = 0 if X == 2;
			gen vote_all = s8q6;
			replace vote_all = 1 if s8q7 == 1;
			label var vote_all "Did you vote in either local or natl elec, GBF";

		* Meeting attendence;
		for var s6q1: replace X = 0 if X == 2;
			gen mtg_attend = s6q1;
			label var mtg_attend "Did you attend any community mtgs in past year? GBF";

		gen g_pta_smc = s4q14 == 1;
		label var g_pta_smc "Member of Parent Teacher Assoc, or School Manage Comm";

		gen g_credit = s4q1 == 1;
		gen g_social = s4q10 == 1;

		* Road Brushing;
		for var s4q13: replace X = 0 if X == 2;
			gen road_brush = s4q13;
			label var road_brush "Have you participated in road brushing? GBF";

		* Name Local Councilor, Name Chief;
		for var s7q3 s7q6 s7q7: replace X = 0 if X == 2;
			gen name_lc = s7q3;
			label var name_lc "Can you name the local councilor? GBF";
			gen name_chief = s7q6;
			label var name_chief "Can you name the paramount chief? GBF";
			gen election_date = s7q7;
			label var election_date "Do you know when the next election is? GBF";

	/* TRUST AND CHURCH */;

		* Church;	
			gen g_church = s4q11 == 1;
			label var g_church "Have you attended church in the last month?";

		* Trust Index from three questions in the trust section;
		for var s5q1 s5q3 s5q5: replace X = 0 if X == 2;
			egen t_index = rsum(s5q1 s5q3 s5q5);
			replace t_index = t_index/3;
			replace t_index = . if s5q1 == .;
			label var t_index "Trust index, simple average of 3 hypothetical GBF questions";

	/* DEMOGRAPHICS */;

		* Female;
		gen female = s1bq3 == 2;
		
		* Ruling/Chief Family;
		gen chief_family = s1cq5 == 1;
			label var chief_family "Household is from a Ruling Family, GBF";

		* Education;  
		/* THIS HAS BEEN CHANGED FOR THE NEWLY CLEANED DATA */;
			gen educ_any = s2bl > 1 & s2bl < 15;
			label var educ_any "Have ever been in school, GBF";	

		* HH Size in 1990;
		gen hhsize_1990 = s2btot;
		label var hhsize_1990 "Size of the household in 1990";

		* Age;
			gen age = 2006 - s1bq4;

		* Demeaned age;
			egen age_m = mean(age);
			gen age_dm = age - age_m; 

	/* SOCIOECONOMIC STATUS */;

		gen radio = s1cq12a == 1;
		label var radio "HH has a radio. GBF";

		gen stove = s1cq12c == 1 | s1cq12d == 1 | s1cq12e == 1 | s1cq12f == 1; 
		label var stove "HH has a stover, GBF";

		gen roof_tin = s1cq6 == 3;
		gen phone = s1cq12h == 1;

		* Earned Cash?;  
		** NB: make this comparable to the IRCBP question "Did you work for wages";
		gen cash = s3bq1j == 1 | s3bq1k == 1 | s3bq1l == 1 | s3bq1m == 1 | s3bq1n == 1 | s3bq1o == 1 ;

	/* INTERACTIONS */;

		foreach var in female age_dm educ_any chief_family{;

			gen i_c_index_`var' = i_c_index*`var';

			};

	*---------------------------------------------------;
	*** Create the sample to be used in the analysis;
	*---------------------------------------------------;

		gen miss = 0;
		foreach var in i_c_index mtg_attend vote_all road_brush g_pta_smc name_lc name_chief t_index g_church 
			   female age educ_any chief_family hhsize_1990 radio stove cash{;
				replace miss = 1 if `var' == .;
			};
		keep if miss==0;

		* Save data file, then work from this temp in the rest of the data;
		save "$data/cp_gbf_analysis", replace;


*--------------------------------------------------------------------------------------------;
* 4) GoBifo 1990 Retrospective Roster Data;
*--------------------------------------------------------------------------------------------;

	* Use the cleaned (published) data;
		use "$raw/gbf-2005_hhroster", clear;


	/* INJURED OR MAIMED DURING THE WAR */;

		gen inj_maim = s2br == 1;
			** NB: The mean of inj_maim in the full sample is 0.06;
			** At the household level, this corresponds to 0.18 of households reporting somebody was injured/maimed/killed;
			** This is below the reported injured/maimed asked directly in the survey, which could be due to sampling for the roster;

	/* LEADERSHIP POSITIONS */;
	
		gen trad_leader = s2bk1 == 1 | s2bk1 == 2 | s2bk1 == 3 | s2bk1 == 4 | s2bk1 == 5 |
				s2bk2 == 1 | s2bk2 == 2 | s2bk2 == 3 | s2bk2 == 4 | s2bk2 == 5 |
				s2bk3 == 1 | s2bk3 == 2 | s2bk3 == 3 | s2bk3 == 4 | s2bk3 == 5 |
				s2bk4 == 1 | s2bk4 == 2 | s2bk4 == 3 | s2bk4 == 4 | s2bk4 == 5;
		gen comm_leader = s2bk1 == 6 | s2bk1 == 7 | s2bk1 == 8 | s2bk1 == 9 | s2bk1 == 10 | s2bk1 == 11 |
				s2bk2 == 6 | s2bk2 == 7 | s2bk2 == 8 | s2bk2 == 9 | s2bk2 == 10 | s2bk2 == 11 |
				s2bk3 == 6 | s2bk3 == 7 | s2bk3 == 8 | s2bk3 == 9 | s2bk3 == 10 | s2bk2 == 11 |
				s2bk4 == 6 | s2bk4 == 7 | s2bk4 == 8 | s2bk4 == 9 | s2bk4 == 10;
		** NB: All of the gov_leader positions are postwar positions, so we don't include them in the selection regressions;

	/* DEMOGRAPHICS */;

		gen female = s2bc ==2;
		gen age_1990 = 1990 - s2bf;
			replace age_1990 = . if age_1990<0;
			replace age_1990 = . if age_1990 > 100;

		gen educ_any = s2bl > 1 & s2bl <15;
		gen still_alive = s2bn == 1;

	*---------------------------------------------------;
	*** Create the sample to be used in the analysis;
	*---------------------------------------------------;

		gen miss = 0;
		foreach var in female age_1990 educ_any inj_maim trad_leader comm_leader{;
				replace miss = 1 if `var' == .;
			};
		keep if miss==0;
	
		*** save as data file;
		save "$data/cp_roster_analysis", replace;


*---------------------------------------------------------------------------------------------------;
* 5) Chiefdom Level Data
*---------------------------------------------------------------------------------------------------;

*-------------------------------------------------------------------------------------------------------;
* 5.a) IRCBP 2005 Public Services Survey;
*-------------------------------------------------------------------------------------------------------;

	/* Only use the 2005 data, because that is as it was before */;
		use "$temp/ps-2005_hh";


	/* COLLAPSE TO CHIEFDOM DATA */;
		collapse (mean) 
				kill_com maim_com kill_hh maim_hh refugee_hh 
				educ_any
				rvote_all 
				mtg_attend_any
				g12 g13
				, by (ch_code);

		* Save to merge on later;
			sort ch_code;
			save "$temp/ch_1", replace;

	/* MERGE IN CHIEFDOM CODES */;
		use "$raw/ch_codes", clear;
		gen ch_code_s = string(ch_code_04cen,"%15.0g");
		rename ch_code_s ch_code;
		sort ch_code;
		merge ch_code using "$temp/ch_1";
		tab _merge; 
		drop if _merge==1;    /* _merge==1 are chiefdoms in Towns, which we merged into the chiefdoms above */;
					    /* Also, Gbo-- Chiefdom in Bo is missing for some reason, so this is a 1	*/;
		drop if _merge==2;    /* This is a wierd Freetown chiefdom that doesn't match any other codes */;
					    /* Should spend more time on this, but not sure where to start	*/;
		drop ch_code_04slihs - ch_code _merge;

	/* CONSTRUCT AND LABEL SOME VARIABLES */;

		* Conflict Variables;
			label var kill_com "(mean) Was anyone from the community maimed or assaulted (IRCBP)";
			label var maim_com "(mean) Did anyone from this community die as a result of the conflict (IRCBP)";
			label var kill_hh "(mean) Were any members of your household killed during the war (IRCBP)";		
			label var maim_hh "(mean) Were any members of your household maimed or injured (IRCBP)";
			label var refugee_hh "(mean) Were any members of your household made refugees(IRCBP)";
	
		* Create a conflict index that includes refugees;
			egen c_index = rsum(kill_com maim_com kill_hh maim_hh refugee_hh);
			replace c_index = c_index/5;
			replace c_index = . if kill_com == .;
			label var c_index "Conflict Index, simple average of all 5 IRCBP measures (IRCBP) ";
			* NB: This is potentially interesting, because 'Was anybody in your household made a refugee' is NOT
				that highly correlated with the other measures (it is correlated with the old conflict index at 
				only around 0.2495);
	
		* Education;
			label var educ_any "(mean) Adults with any schooling (IRCBP)"; 	

		keep ch_code_04cen c_index kill_com maim_com kill_hh maim_hh refugee_hh educ_any;

	*---------------------------------------------------------------------;
	*	Save the data to merge on at the end
	*---------------------------------------------------------------------;
		sort ch_code_04cen;
		save "$temp/ps-2005_hh_c", replace;

*-------------------------------------------------------------------------------------------------------;
* 5.b) 2004 slihs, household data;
*-------------------------------------------------------------------------------------------------------;
	
		use "$raw/slhs-2004_hhexp.dta", clear;
		*Formating;
		format hhid %15.0f;
	
	/* CHIEFDOM ID */;
		* The first 3/4 digits of hid identify chiefdom, and sometimes it is missing a leading 0;
		gen hhid_s = string(hhid,"%15.0g");
		gen l = length(hhid_s);
		tab l;
		replace hhid_s = "0" + hhid_s if l==9;
		gen l2 = length(hhid_s);
		tab l2;
		drop l l2;
		gen ch_code = substr(hhid_s,1,4);
		gen ea_code = substr(hhid_s,5,6);
		gen hhno = substr(hhid_s,7,9);
		sort ch_code;

		* Fix a mistake that Geoff told me about, where two things were given diff. Ch IDs, but were the same;
			replace ch_code = "2104" if ch_code == "2105";

		display "HOW MANY CHIEFDOMS (in HH data)?";
		bys ch_code: gen f = _n==1;
		tab f;	/* NB There are 125 Chiefdoms in the 2004 SLIHS data	*/;
		drop f;

	/* COLLAPSE TO CHIEFDOM DATA */;

		* Now do the collapsing;		
			collapse (mean) pcexpdr, by(ch_code);

		* Save this, because we are going to merge with this;
			sort ch_code;
			save "$temp/ch_2", replace;

	/* MERGE CHIEFDOM IDENTIFIERS */;

		* now get the ch_codes data ready;
			use "$raw/ch_codes", clear;
			gen ch_code_s = string(ch_code_04slihs,"%15.0g");
			gen l = length(ch_code_s);
			tab l;
			replace ch_code_s = "0" + ch_code_s if l==3;
			gen l2 = length(ch_code_s);
			tab l2;
			rename ch_code_s ch_code;
			drop l l2;
			drop ch_code_04slihs - ch_code_trc;
			sort ch_code;

		* Merge this list with the slihs data;
			merge ch_code using "$temp/ch_2";
			tab _merge; 
			drop if _merge==1;    /* _merge==1 are chiefdoms in 2004 census for which we don't have slihs 2004 data */;
			drop _merge;	

	/* LABEL VARIABLES */; 		
		rename pcexpdr pce_04;
		label var pce_04 "(mean) Per Capita Expenditure (regional prices) (2004 slihs)";

	*-----------------------------------------------------------;	
	* Save temp data to be merged together later;
	*-----------------------------------------------------------;	
		sort ch_code_04cen;
		save "$temp/slihs-2004_hh_c", replace;


*-------------------------------------------------------------------------------------------------------;
* 5.c) 2004 slihs, individual level data 
*-------------------------------------------------------------------------------------------------------;

	/* ASSEMBLE THE DIFFERENT PARTS */;

		* Education;
		use "$raw/slhs-2004_sec2.dta", clear;
		sort hhid pid;
		keep region - s2aq4;

		* BMI;
		merge hhid pid using "$raw/slhs-2004_anthro";
		drop _merge;  	/* amazingly, this merge looks perfect, who would have guessed? */;
		sort hhid pid;
	
		* Enrollment of Children;
		merge hhid pid using "$raw/slhs-2004_sec5_b";
		drop _merge;   	/* amazingly, this merge looks perfect, who would have guessed? */;

	/* CHIEFDOM ID */;

		* First need to create a chiefdom ID to merge on;
			gen hhid_s = string(hhid,"%15.0g");
			gen l = length(hhid_s);
			tab l;
			replace hhid_s = "0" + hhid_s if l==9;
			gen l2 = length(hhid_s);
			tab l2;
			drop l l2;
			gen ch_code = substr(hhid_s,1,4);
			gen ea_code = substr(hhid_s,5,6);
			gen hhno = substr(hhid_s,7,9);
			sort ch_code;

		* Fix a mistake that Geoff told me about, where two things were given diff. Ch IDs, but were the same;
			replace ch_code = "2104" if ch_code == "2105";
	
			display "HOW MANY CHIEFDOMS?";
			bys ch_code: gen f = _n==1;
			tab f;		/* NB There are 125 Chiefdoms in the 2004 SLIHS data	*/;

	/* GENERATE SOME VARIALBES OF INTEREST */;

		* Replace 1s and 2s;
			for var s2aq1 s2aq4: replace X = 0 if X ==2;

		* Generate the schooling variables: enrolled in school in 2004 (for kids), ever been to school (for adults);
			gen enroll_04 = s2aq4;
				replace enroll_04 = 0 if s2aq1==0 & s1q5y <= 18; /* enroll is zero if never been in school */;
				replace enroll_04 = . if s1q5y > 18; /* enroll is missing for adults, we only want children's enrollment */;
				replace enroll_04 = . if s1q5y <5;   /* enroll is missing for children under five, get enrollment for 5-18 year olds */;
			gen eversch_04 = s2aq1;
				replace eversch_04 = . if s1q5y < 18; /* want to look at eversch for adults only */;

		* Generate BMI for children;
			gen meters = s7anq4/100;
			gen kg = s7anq5;
			gen meters_sq = meters*meters;
			gen bmi_child_04 = kg/meters_sq;
			replace bmi_child_04 = . if s1q5y>5;		/* These seem to be really wierd outliers */;
			replace bmi_child_04 = . if bmi_child_04 < 5; 	/* These seem to be really wierd outliers (less than 1% of sample)*/;
			replace bmi_child_04 = . if bmi_child_04 > 100; /* These seem to be really wierd outliers (roughly 5% of sample)*/;

	/* COLLAPSE TO CHIEFDOM DATA */;

		* Collapse the data at the chiefdom level;
			collapse (mean) enroll_04 eversch_04 bmi_child_04, by(ch_code);

		* Save this, because we are going to merge with this data set in a second;
			sort ch_code;
			save "$temp/ch_3", replace;

	/* MERGE CHIEFDOM IDENTIFIERS */;
		* Use the list of Chiefcodes developed previously;
			use "$raw/ch_codes", clear;
			gen ch_code_s = string(ch_code_04slihs,"%15.0g");
			gen l = length(ch_code_s);
			tab l;
			replace ch_code_s = "0" + ch_code_s if l==3;
			gen l2 = length(ch_code_s);
			tab l2;
			rename ch_code_s ch_code;
			drop l l2;
			drop ch_code_04slihs - ch_code_trc;	
			sort ch_code;

		* Merge this list with the slihs data;
			merge ch_code using "$temp/ch_3";
			tab _merge; 
			drop if _merge==1;    /* _merge==1 are chiefdoms in 2004 census for which we don't have slihs 2004 data */;
			drop _merge;

	/* LABEL VARIABLES */;
		label var enroll_04 "(mean) Child is enrolled in school (2004 slihs)";
		label var eversch_04 "(mean) Adult has ever attended school (2004 slihs)";
		label var bmi_child_04 "(mean) Child (<5 years) BMI (kg/m^2) (2004 slihs)";

	*-----------------------------------------------------;
	* Save the data to be merged later;
	*-----------------------------------------------------;	
		sort ch_code_04cen;
		save "$temp/slihs-2004_indiv_c", replace;


*-------------------------------------------------------------------------------------------------------;
*  5.d) 1989 household survey;
*-------------------------------------------------------------------------------------------------------;

	use "$raw/hh-1989", clear;

		*Formating;
		format hid eano hhsize age %15.0f;
		rename district district_1989;

	/* FIX PROBLEM, THEN MAKE CHIEFDOM CODES */;
		* Apparently, sometimes more than one household has the same hid.  We can tell this because there are
		* multiple income values per hid.  We can fix that by assigning each set of income within an hid a new hid;
	
		bys hid totfood: gen f = _n==1;
		bys eano: gen n_hid = sum(f);
		drop f;

		gen eano_s = string(eano,"%15.0g");	
		gen new_hid_s = string(n_hid);
		gen l = length(new_hid_s);
		tab l;
		replace new_hid_s = "0" + new_hid_s if l==1;
		
		replace new_hid_s = eano_s + new_hid_s;
		drop eano_s;
		gen l2 = length(new_hid_s);
		tab l2;	
		drop l l2;
		label var new_hid_s "HH ID: Digits 1-4 Chiefdom, 5-6 EA, 7-8 HH";
		
		drop hid;

	* First need to create a chiefdom ID to merge on;
	* NB This comes from the first 3/4 digits of the eano, sometimes missing a leading 0;
		gen eano_s = string(eano,"%15.0g");
		gen l = length(eano_s);
		tab l;
		replace eano_s = "0" + eano_s if l==5;
		gen l2 = length(eano_s);
		tab l2;
		drop l l2;
		gen ch_code = substr(eano_s,1,4);
		sort ch_code;

	/* COLLAPSE AND GET INCOME DATA */;

		*** as these are hh variables, only want one obs. per household;
		*** preserve the data, then save only one obs per household, the collapse, then restore;
	
		preserve;	
			bys new_hid: keep if _n==1;
			count;
		
			gen pce_89 = pce;

			collapse (mean) pce_89, by(ch_code);
	
			save "$temp/ch_4a", replace;
		restore;

	/* COLLAPSE AND GET ENROLLMENT IN SCHOOL */;

		** education variables;

		gen enroll_89 = enrol;
		replace enroll_89 = . if age > 18; 		/* enrollment is only relevant for children <= 18 years */;
		replace enroll_89 = . if age < 5;		/* also only want children over 5 years old, to be consistent with 2004 */;
	
		gen eversch_89 = level>=1;
		replace eversch_89 = . if age < 18;

		collapse (mean) eversch_89 enroll_89, by(ch_code);

		* merge the household and the individual chiefdom means together;
		merge ch_code using "$temp/ch_4a";
		tab _merge;
		drop _merge;

		* Save at this point, we are going to merge this in a second;
		sort ch_code;
		save "$temp/ch_4", replace;

	/* MERGE IN CHIEFDOM IDS */;

		* Need to get the right chiefdom identifiers from the other data;
			use "$raw/ch_codes", clear;
			gen ch_code_s = string(ch_code_85cen,"%15.0g");
			gen l = length(ch_code_s);
			tab l;
			replace ch_code_s = "0" + ch_code_s if l==3;
			gen l2 = length(ch_code_s);
			tab l2;
			drop l l2;
			drop ch_code_04slihs - ch_code_trc;	
			rename ch_code_s ch_code;

		sort ch_code;

		* Merge this list with the 1989 data;
			merge ch_code using "$temp/ch_4";
			tab _merge; 
			drop if _merge==1;    /* _merge==1 are chiefdoms in 2004 census for which we don't have 1989 data */;
			drop _merge;		/* We should have 1989 data for 72 chiefdoms */;

	/* LABEL VARIABLES */;

		label var pce_89 "(mean) 1989 HH per capita income (1989 slhs)";
		label var enroll_89 "(mean) Children enrolled in school (1989 slhs)";
		label var eversch_89 "(mean) Ever been to school for all (for adults) (1989 slhs)";

	*----------------------------------------------------;
	* Save data to merge on at the end;
	*----------------------------------------------------;
		sort ch_code_04cen;
		save "$temp/hh-1989_c", replace;


*-------------------------------------------------------------------------------------------------------;
*  5.e) GIS DATA;
*-------------------------------------------------------------------------------------------------------;

	* Use the cleaned data;
	* Obtained from Sierra Leone Information Systems (SLIS) GIS files;
		use "$raw/slis-2004_gis.dta", clear;

	/* ALREADY AT CHIEFDOM LEVEL, DON'T NEED TO COLLAPSE */;

		* Save, because we are going to merge on this in a second;
		rename ch_code_slis ch_code;
		sort ch_code;
		save "$temp/ch_5", replace;

	/* MERGE IN CHIEFDOM IDENTIFIERS */;

		use "$raw/ch_codes", clear;
		gen ch_code = ch_code_slis;
		* Need to get the right chiefdoms for WA Rural, start by giving them all the WA totals;
			replace ch_code = 150 if district == "Western Area Rural";
		sort ch_code;
		merge ch_code using "$temp/ch_5";
		tab _merge; 
		drop if _merge==1;    /* _merge==1, 7 Freetown chiefdoms, 5 towns */;
		drop ch_code_04slihs - ch_code _merge;

	/* GIVE WA RURAL 1/4 OF THE WA TOTALS */;
		* NB: We do this because we don't have separate data for each of the WA Rural chiefdoms, 
			so just assume everything evenly spread;
		replace allmining = allmining/4 if ch_code_04cen == 4101 | 
					ch_code_04cen == 4102 | ch_code_04cen == 4103 |ch_code_04cen == 4104;
		replace diamonds = diamonds/4 if ch_code_04cen == 4101 | 
					ch_code_04cen == 4102 | ch_code_04cen == 4103 |ch_code_04cen == 4104;
		replace nondiamonds = nondiamonds/4 if ch_code_04cen == 4101 
					| ch_code_04cen == 4102 | ch_code_04cen == 4103 |ch_code_04cen == 4104;
		replace area = area/4 if ch_code_04cen == 4101 | ch_code_04cen == 4102 
					| ch_code_04cen == 4103 |ch_code_04cen == 4104;

	/* Label variables */;
		label var allmining "Total Registered Mining Plots (GIS)";
		label var diamonds "Total Registered Diamond Mines (GIS)";
		label var nondiamonds "Total Registered Non-Diamond Mines (GIS)";
		label var area "Area of chiefdom (GIS)";
		label var roaddensity "Road Density (GIS)";
		label var riverdensity "River Density (GIS)";
		label var distance_to_freetown "Distance to Freetown (GIS)";
		

	* Drop a few un-needed variables;
	drop roadcells rivercells;

	*----------------------------------------------------;
	*  Save this data to merge on at the end;
	*----------------------------------------------------;	
	sort ch_code_04cen;
	save "$temp/gis_c", replace;


*--------------------------------------------------------------------------------------------------------;
* 5.f) NGO project incidence;
*--------------------------------------------------------------------------------------------------------;

	* Use clean data;	
	* Obtained from Sierra Leone Information Systems (SLIS) Encyclopedia 2004;
	 	use "$raw/slis-2004_ngo.dta", clear;

	/* ALREADY AT CHIEFDOM LEVEL, DON'T NEED TO COLLAPSE */;

		* Save because we merge on this later;
			rename ch_code_slis ch_code;
			sort ch_code;
			save "$temp/ch_6", replace;

	/* MERGE CHIEFDOM IDENTIFIERS */;

		use "$raw/ch_codes", clear;
		gen ch_code = ch_code_slis;
		sort ch_code;

		* Merge this list with the NGO data;
		merge ch_code using "$temp/ch_6";
		tab _merge; 			/* Merge == 1 are 7 Freetown, 4 WA Rural, 5 Towns */;

	/* LABEL VARIABLES */;

		*Here we need to fix the identifiers on the (4) Western Area Rural districts;
		replace district  = "Western Area Rural" if chiefdom  == "Mountain Rural";
		replace ch_code_04cen = 4102 if chiefdom == "Mountain Rural";
		replace ch_nm_04cen = "Mountain" if chiefdom == "Mountain Rural";
	
		replace district  = "Western Area Rural" if chiefdom  == "Koya Rural";
		replace ch_code_04cen = 4101 if chiefdom == "Koya Rural";
		replace ch_nm_04cen = "York" if chiefdom == "Koya Rural";
	
		replace district  = "Western Area Rural" if chiefdom  == "York Rural";
		replace ch_code_04cen = 4104 if chiefdom == "York Rural";
		replace ch_nm_04cen = "York" if chiefdom == "York Rural";
	
		replace district  = "Western Area Rural" if chiefdom  == "Waterloo";
		replace ch_code_04cen = 4103 if chiefdom == "Waterloo";
		replace ch_nm_04cen = "Waterloo" if chiefdom == "Waterloo";
		drop if _merge==1;    /* _merge==1 are the Western Area chiefdoms that I dealt with above
						note that these got dropped by District==""*/;
		drop _merge;

		rename total_proj ngo_tot;
		label var ngo_tot "Total Number of NGO projects in Chiefdom (WWW data)";

		drop ch_code_04slihs - chiefdom;

		keep district ch_code_04cen ch_nm_04cen ngo_tot;
		order district ch_code_04cen ch_nm_04cen;
	
	*----------------------------------------------------;
	*  Save the data;
	*----------------------------------------------------;	
		sort ch_code_04cen;
		save "$temp/ngo_c", replace;

*--------------------------------------------------------------------------------------------------------;
* 5.g) Now do this for Population Data;
*--------------------------------------------------------------------------------------------------------;

	* Use the cleaned data;
	* Obtained from 2001 projections (obtained before census data was available), SLIS 2004;	
		use "$raw/slis-2004_population.dta", clear;

	/* ALREADY AT CHIEFDOM LEVEL, DON'T NEED TO COLLAPSE */;

		* Have a little problem with Freetown, because they all have the same Geocode;
		* We are going to drop Freetown anyways, so do that here;
			bys geocode: keep if _n==1;
	
		* Save because we are going to merge on this in a second;
			rename geocode ch_code;
			sort ch_code;
			save "$temp/ch_7", replace;

	/* MERGE IN CHIEFDOM IDENTIFIERS */;
		use "$raw/ch_codes", clear;
		gen ch_code = ch_code_slis;
		sort ch_code;
		merge ch_code using "$temp/ch_7";
		tab _merge; 	/* _merge==1 for 7 Freetown areas, 4 WA Rural, 5 Towns */;

		* As above, we need to deal with the Western Area Rural chiefdoms;
		replace ch_code_04cen = 4102 if chiefdom == "Moutain";
		replace ch_nm_04cen = "Mountain" if chiefdom == "Moutain";
	
		replace ch_code_04cen = 4101 if chiefdom == "Koya" &  ch_code==991;
		replace ch_nm_04cen = "York" if chiefdom == "Koya" & ch_code==991;
	
		replace ch_code_04cen = 4104 if chiefdom == "York";
		replace ch_nm_04cen = "York" if chiefdom == "York";
	
		replace ch_code_04cen = 4103 if chiefdom == "Waterloo";
		replace ch_nm_04cen = "Waterloo" if chiefdom == "Waterloo";

		drop ch_code_04slihs - chiefdom;
		drop if _merge==1;    /* _merge==1 are the Western Area chiefdoms that I dealt with above*/;
		drop _merge;


	/* LABELING */;
		
		label var pop_1985 "Chiefdom population in 1985 (1985 Census)";
		label var pop_2001cso "Chiefdom population (projected) in 2001 (Ency 03)";
		label var total_returns "Total displaced people (both IDP and refugees) (Ency 03)";
		label var percent_displaced "Diplaced People / 2001 Population (Ency 03)";
		drop idps* pop_2001cso total_returns percent_displaced;

	*----------------------------------------------------;
	* Save the data;
	*----------------------------------------------------;
		sort ch_code_04cen;
		save "$temp/population_c", replace;

*--------------------------------------------------------------------------------------------------;
* 5.h) NPWJ data;
*--------------------------------------------------------------------------------------------------;

	*--------------------------------------------------------------------------------------------------;
	***	This section takes a slightly different form (because I wrote it at a different time)
	***	- Cleaning the NPWJ for mis-spellings and codings
	***	- Creating Chiefdom-level totals of the number of incidents/killings/etc
	***		 Save an event-level version of the data "$data/npwj_events"
	***	- Collapse the data to chiefdom levels and merge in the Chiefdom Code Identifiers 
	***	- Merging in Conflict data and Population data
	***		4Save a chiefdom-level version of the data "$temp/npwj_c"
	*--------------------------------------------------------------------------------------------------;

	*--------------------------------------------------------------------------------------------------;
	**  Cleaning the data for mis-spellings and codings;
	*--------------------------------------------------------------------------------------------------;
	
	* Use the latest raw data, which includes update sent by Benn May 1, 2007;
		use "$raw/npwj-2004";  
		drop var*;
	

	/* FIX MISTAKES IN CHIEFDOM NAMES */;

		* Bo District;
			replace ch_nm_npwj = "Badjia" if ch_nm_npwj == "Badija" & district == "Bo";
			replace ch_nm_npwj = "Tikonko" if ch_nm_npwj == "Tinkoko" & district == "Bo";
			replace ch_nm_npwj = "Bagbwe" if ch_nm_npwj == "Bagbe"  & district == "Bo";
			replace ch_nm_npwj = "Baoma" if ch_nm_npwj == "Boamba"  & district == "Bo";
			replace ch_nm_npwj = "Baoma" if ch_nm_npwj == "Boama"  & district == "Bo";
			replace ch_nm_npwj = "Bumpe Ngawo" if ch_nm_npwj == "Bumpeh"  & district == "Bo";
			replace ch_nm_npwj = "Gbonkolenken" if ch_nm_npwj == "Gbo"  & district == "Bo";
			replace ch_nm_npwj = "Jaiama-Bongor" if ch_nm_npwj == "Jiama Bongor"  & district == "Bo";
			replace ch_nm_npwj = "Komboya" if ch_nm_npwj == "Kombaya"  & district == "Bo";

		* Bonthe District;
			replace ch_nm_npwj = "Bonthe Town" if ch_nm_npwj == "York Island" & district == "Bonthe";;
			replace ch_nm_npwj = "Kpanga Kemo" if ch_nm_npwj == "Kpanda Kemo" & district == "Bonthe";
			drop if ch_nm_npwj == "Banta" & district == "Bonthe";

		* Bombali District;
			replace ch_nm_npwj = "Gbendembu Ngowahun" if ch_nm_npwj == "Gbendembu Ndowahun" & district == "Bombali";
			replace ch_nm_npwj = "Sanda Loko" if ch_nm_npwj == "Sando Loko" & district == "Bombali";
			replace ch_nm_npwj = "Magbaimba Ndorhahun" if ch_nm_npwj == "Magbaiamba Ndowahun" & district == "Bombali";;
			
		* Kailahun District;
			replace ch_nm_npwj = "Dea" if ch_nm_npwj == "Dia" & district == "Kailahun";
			replace ch_nm_npwj = "Kpeje West" if ch_nm_npwj == "Peje West" & district == "Kailahun";
			replace ch_nm_npwj = "Kpeje Bongre" if ch_nm_npwj == "Peje Bongre" & district == "Kailahun";
			replace ch_nm_npwj = "Jawie" if ch_nm_npwj=="Jawei" & district == "Kailahun";

		* Kambia District;
			replace ch_nm_npwj = "Gbinle-Dixing" if ch_nm_npwj == "Gbinleh Dixon" & district == "Kambia";
			replace district = "Kambia" if ch_nm_npwj == "Mambolo" & district == "Koinadugu";
			replace ch_nm_npwj = "Tonko Limba" if ch_nm_npwj == "Tonka Limba" & district == "Kambia";

		*Kenema;
			replace ch_nm_npwj = "Kandu Lekpeama" if ch_nm_npwj == "Kandu Leppema" & district == "Kenema";;

		* Koinadugu District;
			replace ch_nm_npwj = "Diang" if ch_nm_npwj=="Dieng" & district == "Koinadugu";
			replace ch_nm_npwj = "Mongo" if ch_nm_npwj == "Mangolo" & district == "Koinadugu";
			replace ch_nm_npwj = "Mongo" if ch_nm_npwj=="Mondo" & district == "Koinadugu";
			replace ch_nm_npwj = "Wara Wara Bafodi" if ch_nm_npwj== "Wara Wara Bafodia" & district == "Koinadugu";
			replace ch_nm_npwj = "Nieni" if ch_nm_npwj == "Neini" & district == "Koinadugu";;
			replace ch_nm_npwj = "Kasunko" if ch_nm_npwj == "Kasongo" & district == "Koinadugu";
			replace ch_nm_npwj = "Dembelia Sinkuni" if ch_nm_npwj == "Dembelia Sinkuria" & district == "Koinadugu";
		
		* Kono District;
			replace ch_nm_npwj = "Fiama" if ch_nm_npwj == "Siama" & district == "Kono";
			replace ch_nm_npwj = "Nimikoro" if ch_nm_npwj == "Nimidoro" & district == "Kono";
			replace ch_nm_npwj = "Tankoro" if ch_nm_npwj == "Takoro" & district == "Kono";
			replace district = "Kono" if ch_nm_npwj == "Gbane" & district == "Kailahun";
			replace ch_nm_npwj = "Sandor" if ch_nm_npwj == "Sandoh" & district == "Koinadugu";
			replace district = "Kono" if ch_nm_npwj == "Sandor" & district == "Koinadugu";

		* Moyamba;
			replace ch_nm_npwj = "Bumbeh" if ch_nm_npwj == "Bumpe Ngawo" & district == "Moyamba";
			replace ch_nm_npwj = "Upper Banta" if ch_nm_npwj == "Banta Mokele" & district == "Moyamba";
			replace ch_nm_npwj = "Lower Banta" if ch_nm_npwj == "Banta" & district == "Moyamba";
			replace ch_nm_npwj = "Bumpeh" if ch_nm_npwj == "Bumbeh";
			replace ch_nm_npwj = "Kaiyamba" if ch_nm_npwj == "Kayima";		

		* Port Loko;
			replace ch_nm_npwj = "Sanda Magbolonto" if ch_nm_npwj == "Sanda Magbolontor";
	
		* Pujehun;
			replace ch_nm_npwj = "Kpanga-Kabonde" if ch_nm_npwj == "Panga Kbonde" & district == "Pujehun";
			replace ch_nm_npwj = "Kpanga-Kabonde" if ch_nm_npwj == "Panga Kabone" & district == "Pujehun";
			replace ch_nm_npwj = "Pejeh" if ch_nm_npwj == "Peje" & district == "Pujehun";
			replace district = "Pujehun" if ch_nm_npwj == "Makpele" & district == "Kenema";	

		* Tonkolili;
			replace ch_nm_npwj = "Kunike Barina" if ch_nm_npwj == "Konike Barina" & district == "Tonkolili";
			replace ch_nm_npwj = "Kunike Barina" if ch_nm_npwj == "Konikia Barina" & district == "Tonkolili";
			replace ch_nm_npwj = "Kunike Sanda" if ch_nm_npwj == "Konike Sanda" & district == "Tonkolili";
			replace ch_nm_npwj = "Kunike Sanda" if ch_nm_npwj == "Konikia Sanda" & district == "Tonkolili";
			replace ch_nm_npwj = "Sambaya" if ch_nm_npwj == "Sambaia Bendugu" & district == "Tonkolili";
			replace ch_nm_npwj = "Kalansogoia" if ch_nm_npwj == "Kalansagoia" & district == "Tonkolili";

		* Western Area;
			replace ch_nm_npwj = "York Rural" if ch_nm_npwj == "York" & district == "Western Area Rural";

	/* CREATE SOME NEW CATEGORICAL VARIABLES AND STANDARDIZE SOME SPELLINGS */;

		* Need to standardize the rebel groups for the purposes of making the variables below;
			replace agroup_a = "RUF" if agroup_a == "RUF/AFRC" | agroup_a == "RUF/NPFL" | agroup_a == "NPFL" | agroup_a == "AFRC";
			replace agroup_a = "CDF" if agroup_a == "CDF/Kamajors" | agroup_a == "militia" | agroup_a == "CDF/ECOMOG"
				| agroup_a == "Kamajor" | agroup_a == "Kamajor/Gbethis/Ecomog/SLA" | agroup_a == "townspeople" | agroup_a == "local youths"
				| agroup_a == "Gbethis";
	
		* Replace 'Brutality' with 'Atrocity', to be more in step with Human Rights Literature;
			replace desc = "Atrocity" if desc== "Brutality";
	
		*Deal with some of the mis-spellings or ambiguities;
			replace desc = "Attack" if desc == "Attacks";
			replace desc = "Battle" if desc == "Battles" | desc == "Batle" | desc == "Airfield" | desc == "main troop position" ;
			replace desc = "Atrocity" if desc == "Harassment";
			replace desc = "Troop Movement" if desc == "Troop movement" |  desc == "Execution Center" | desc == "Control" | desc == "Base / HQ";
	
	/* BINARY FOR WHETHER PEOPLE WERE KILLED */;
		*NB: data comes in strings, and we need binary;
		
		foreach x in killed burned raped maimed abducted{; 
			rename `x' `x'_old;
			gen `x' = `x'_old == "YES" | `x'_old == "yes" | `x'_old == "yse" | `x'_old == "1";
		*	drop `x'_old;
		};

		label var killed "Somebody was killed during the incident";
		label var burned "Houses/building were burned during the incident";
		label var raped "Somebody was raped/sexually assaulted during the incident";
		label var maimed "Somebody was maimed/severe HR violations during the incident";
		label var abducted "Somebody was abducted during the incident";

	*-----------------------------------------------------------------------------------------------------;
	*** Create the variables we are interested in for the analysis;
	*------------------------------------------------------------------------------------------------------;

	/*  For main analysis, we need two variables: number of RUF bases and number of attacks and battles in a chiefdom */;

		foreach y in Attack Atrocity Battle Base {;
			gen `y' = desc== "`y'" ;
			bys ch_nm_npwj: egen n_`y' = sum(`y'); 
			label var n_`y' "The number of `y's in chiefdom";
		};

		bys ch_nm_npwj: egen n_ruf_base = sum(ruf_base);
		label var n_ruf_base "Number of RUF bases in chiefdom (NPWJ)";

		gen atbt = desc == "Battle" | desc == "Attack" ;
		bys ch_nm_npwj: egen n_atbt = sum(atbt); 
		label var n_atbt "Number of Attacks & Battles in Chiefdom (NPWJ)";

	/*  Also need to identify places where chiefs were targeted	*/;
		
		* This is taken out of the notes column in the Excel spreadsheet, so put in data by hand;
			gen target_chief = 0;
			local rep "replace target_chief = 1 if";
			`rep'  e_id == 1 & district == "Bonthe";
			`rep'  e_id == 6 & district == "Bonthe";		
			`rep'  e_id == 7 & district == "Bonthe";
			`rep'  e_id == 24 & district == "Bonthe";
			`rep'  e_id == 112 & district == "Bonthe";
			`rep'  e_id == 268 & district == "Kenema";
			`rep'  e_id == 290 & district == "Kenema";
			`rep'  e_id == 29 & district == "Kono";
			`rep'  e_id == 133 & district == "Bo";
			`rep'  e_id == 139 & district == "Bo";
			`rep'  e_id == 125 & district == "Port Loko";
			`rep'  e_id == 2 & district == "Moyamba";
			`rep'  e_id == 5 & district == "Moyamba";
			`rep'  e_id == 18 & district == "Moyamba";
			`rep'  e_id == 67 & district == "Moyamba";
			`rep'  e_id == 76 & district == "Moyamba";
			`rep'  e_id == 96 & district == "Moyamba";
			bys ch_nm_npwj: egen n_target_chief = sum(target_chief);
			drop target_chief;
			gen target_chief = n_target_chief>0;
			label var target_chief "Traditional Authority was targeted (NPWJ)";

	*-------------------------------------------------------------------------;
	* This is still observation-by-observation, so save a version right now;
	*-------------------------------------------------------------------------;
		save "$temp/npwj_events", replace;

	*--------------------------------------------------------------------------------------------;
	* Collapse the data to the chiefdom level;
	*---------------------------------------------------------------------------------------------;
		
		/* We just want chiefdom-level observations of the totals at the moment */;

			* First, just keep the chiefdom-level totals of the variables of interest;
			keep district ch_nm_npwj n_atbt n_ruf_base target_chief;
			bys district ch_nm_npwj: keep if _n== _N;		/* Just keep the last observation per chiefdom	*/;
			gen ch_nm = ch_nm_npwj;					/* we are going to merge on this in a second */;
			sort district ch_nm;		
			save "$temp/sl_10", replace; 		


	*--------------------------------------------------------------------------------------------;
	* Merge Chiefdom identifiers;
	*---------------------------------------------------------------------------------------------;

		* Merge into the ch_codes so we can have the 2004 census codes, which we use throughout;
			use "$raw/ch_codes", clear;
				gen ch_nm = ch_nm_04cen;
				sort district ch_nm;
			merge district ch_nm using "$temp/sl_10";
				tab _merge;
				drop ch_code_04slihs - ch_nm;
	
		/* NB: There are a few (4) chiefdmoms that don't have any information about them in the report, 
			set all the values to 0*/;
			* Loko Massama Chiefom, Port Loko District/ Toli Chiefdom, Kono/ Paki Masabong Chiefdom, Bombali /
				 YKK Chiefdom, Pujehun;
			foreach var in n_atbt n_ruf_base target_chief{;		
				replace `var' = 0 if ch_nm_04cen == "Lokomasama" | ch_nm_04cen == "Toli" | 
					ch_nm_04cen == "Paki Masabong" | ch_nm_04cen == "YKK";
			};	
	
			* We don't want to loose these 4 chiefdoms;
			replace _merge = 3 if ch_nm_04cen == "Lokomasama" | ch_nm_04cen == "Toli" | 
					ch_nm_04cen == "Paki Masabong" | ch_nm_04cen == "YKK";
				
				list district ch_nm_04cen if _merge~=3;
			
			drop if _merge~=3;  /* We are losing Freetown, the other 'Towns' and
						a few events where no chiefdom was recorded */;
			drop _merge;

	*-------------------------------------------------------------------------;
	* Save a chiefdom-level version of this data-set;
	*-------------------------------------------------------------------------;
		sort ch_code_04cen;
		save "$temp/npwj_c", replace;
	

*--------------------------------------------------------------------------------------------------------;
* 5.i) School Data;
*--------------------------------------------------------------------------------------------------------;

	* NB: We are going to have to do this measure by measure because of the nature of the data;

		/* TEACHER ABSENT ON DAY OF SURVEY */;

			* Need to use combined roster, from Liz Nov 21 2006;
			use "$raw/sch-2005_roster", clear;
		
			sort schoolid;
			by schoolid: gen tot_obs = _N;
			recode c26_here (1 = 1) (2 = 0);
			by schoolid: gen tot_present = sum(c26_here);
			by schoolid: keep if _n == _N;
			gen teach_present = tot_present/tot_obs;
				label var teach_present "Fraction of Teachers Present (sch)";
			gen teach_absent = 1 - teach_present;			
				label var teach_absent "Fraction of Teachers Absent (sch)";

				** NB: numbers match the IRCBP report;
	
			keep schoolid chief_2004census teach_absent;
			sort schoolid;
			save "$temp/sch1", replace;


		/* SCHOOL VISITED BY CHIEF? */;

			* Use cleaned data, from Liz Nov 21 2006;
			use "$raw/sch-2005_facility", clear;
					
			* "Has this school been visited by a Chief?";
			replace d243 = 0 if d243 == 2;
				rename d243 schvisit_chief;
					label var schvisit_chief "Visited by a chief (sch)";
					* NB: Numbers match the IRCBP report;
	
		/* SCHOOL RECEIVED SUPPORT FROM COMMUNITY, NGOs, OR PARENTS? */;

			* "Did this school receive any donor or NGO support last year";
				replace d332 = 0 if d332 == 2;
				replace d332 = . if d332 == 3;
				rename d332 schreceive_NGO;
				label var schreceive_NGO "Received NGO support last yr (sch)";

			* "Did the school receive any support from the community last year?";
				replace d337 = 0 if d337 == 2;
				replace d337 = . if d337 == 4;	/* Only one observation, implausible value, so drop it */;
				rename d337 schreceive_comm;
				label var schreceive_comm "Received community support last year (sch)";
				*NB: These numbers all match the numbers in the IRCBP report;

			keep schoolid chief_2004census schreceive_comm schreceive_NGO schvisit_chief;
			sort schoolid;
			merge schoolid using "$temp/sch1";
			drop _merge;
			sort schoolid;

	/* CREATE CHIEFDOM IDENTIFIER */;
		
		gen ch_code = chief_2004census;
		
		** As with the IRCBP data, need to put the Towns back into their chiefdoms;
			replace ch_code = 2102 if ch_code == 2191 ;  /* Makeni Town in Bombali Shebora Chiefdom*/;
			replace ch_code = 3108 if ch_code == 3191 ;  /* Bo Town in Kakua Chiefdom */;
			replace ch_code = 1212 if ch_code == 1291 ;  /* Kenema Town in Nongowa Chiefdom */;
			replace ch_code = 1304 if ch_code == 1391 ;  /* Koidu Town in Gbense Chiefom*/;
			replace ch_code = 3209 if ch_code == 3291 ;  /* Bonthe Town in Sittia Chiefdom*/;
			replace ch_code = 3209 if ch_code == 3212;

		* Freetown ;
			replace ch_code = 4201 if ch_code == 4200;  /* NB: this will be dropped later, so doesn't matter */;

	/* COLLAPSE DATA TO CHIEFDOM LEVEL */;

		collapse (mean) teach_absent schreceive_comm schreceive_NGO schvisit_chief, by(ch_code);
			label var teach_absent "(mean) Fraction of Teachers Absent (sch)";			
			label var schvisit_chief "(mean) visited by a chief (sch)";
			label var schreceive_NGO "(mean) Received NGO support last yr (sch)";
			label var schreceive_comm "(mean) Received community support last year (sch)";

		* Save, because we are going to merge on this in a second;
			sort ch_code;
			save "$temp/ch_11", replace;

	/* MERGE CHIEFDOM IDENTIFIERS */;

		* Use the list of Chiefcodes developed previously;
		use "$raw/ch_codes", clear;
		gen ch_code = ch_code_04cen;
		sort ch_code;
		merge ch_code using "$temp/ch_11";
		tab _merge;
		drop if _merge==1;    /* _merge==1 is chiefdoms with no school data (56 of them) */;
		drop if _merge == 2;
		drop ch_code_04slihs - ch_code _merge;

	*----------------------------------------------------;
	*  Save this data set as "$SL_data/school_c";
	*----------------------------------------------------;	
		sort ch_code_04cen;
		save "$temp/sch-2005_c", replace;


*-------------------------------------------------------------------------------------;
* 5.j) FINALLY, MERGE EVERYTHING TOGETHER to get the Chiefdom Level Data;
*-------------------------------------------------------------------------------------;

	* Start with hh2004_hh_c;
		use "$temp/slihs-2004_hh_c", clear;
		sort ch_code_04cen;

	* hh2004_indiv_c;
		merge ch_code_04cen using "$temp/slihs-2004_indiv_c";
			tab _merge;
			drop _merge;
			sort ch_code_04cen;
	* hh1989;
		merge ch_code_04cen using "$temp/hh-1989_c";
			tab _merge;
			drop _merge;
			sort ch_code_04cen;
	* IRCBP Public Services;
		merge ch_code_04cen using "$temp/ps-2005_hh_c";
			tab _merge;
			drop _merge;
			sort ch_code_04cen;
	* GIS data;
		merge ch_code_04cen using "$temp/gis_c";
			tab _merge;
			drop _merge;
			sort ch_code_04cen;
	* NGO data;
		merge ch_code_04cen using "$temp/ngo_c";
			tab _merge;
			drop _merge;
			sort ch_code_04cen;
	* Population data;
		merge ch_code_04cen using "$temp/population_c";
			tab _merge;
			drop _merge;
			sort ch_code_04cen;
	* NPWJ data;
		merge ch_code_04cen using "$temp/npwj_c";
			tab _merge;
			drop _merge;
			sort ch_code_04cen;

	* School data;
		merge ch_code_04cen using "$temp/sch-2005_c";
			tab _merge;
			drop _merge;
			sort ch_code_04cen;

	* Need to replenish the district;
		drop district;
		merge ch_code_04cen using "$raw/ch_codes";
		drop if _merge == 2;
		drop _merge;

*-------------------------------------------------------------------------------------;
* 5.k) Create some variables that use multiple datasets, rename some stuff;
*-------------------------------------------------------------------------------------;

	*** Create Population Density;
		gen pop_dens_85 = pop_1985/area;
		label var pop_dens_85 "Population Density in 1985 (1985 census)";
		gen lpop_dens_85 = log(pop_dens_85);
		label var lpop_dens_85 "Log population Density 1985";
		
	*** Logs for distance and income;
		gen ldistance = log(distance_to_freetown);
		label var ldistance "Log Distance to Freetown (GIS)";
		gen lpce_89 = log(pce_89);
		label var lpce_89 "(mean) Log Per Capita Expenditure (1989 slhs)";
		gen lpce_04 = log(pce_04);
		label var lpce_04 "(mean) Log Per Capita Expenditure (2004 slihs)";
		
	*** Create District Fixed Effects;
		tab district, gen(d);
*		tab district, gen(d);


*-------------------------------------------------------------------------------------;
* 5.l) Create the sample to be used in the analysis and SAVE!!;
*-------------------------------------------------------------------------------------;
/*;
	*** Drop Freetown;
		drop if district == "Western Area Urban";

	*** Restrict this to just the sample we are working with;
		gen sample_large = c_index ~=. & pop_1985~=.;

	*** Want summary statistics for the chiefdoms in the large sample;
		keep if sample_large==1;  drop sample_large;
*/;

	*** Merge this back in the chief_codes, so we can get the right chiefdom names;
		drop ch_nm_04cen;
		sort ch_code_04cen;
		merge ch_code_04cen using "$raw/ch_codes", keep(ch_nm_04cen);
		tab _merge;  drop if _merge == 2;  drop _merge;

	*** Put notes in there with the sources;
		note: KEY TO DATA SOURCES;
		note: IRCBP: 2005 IRCBP Public Services Survey;
		note:	2004 slihs: 2004 Sierra Leone Integrated Household Survey;
		note: 1989 slhs: 1989 Sierra Leone Household Survey;
		note: GIS: Sierra Leone GIS data;
		note: 1985 Census: 1985 Census data;
		note: WWW: Sierra Leone Information Systems NGO data;
		note: NPWJ: No Peace Without Justice conflict mapping project;
		note: sch: 2005 IRCBP School Survey; 

	*** Put in Chiefdom Headquarters GPS coordinates for Ted;
		ren ch_code_slis ch_code_gis;
		sort ch_code_gis;
		merge ch_code_gis using "$raw/hq_gps";
		tab _merge;
		drop _merge;	
		replace ch_code_gis = . if ch_code_gis == 151;
		replace ch_code_gis = . if ch_code_gis == 152;
		label var hq_x "Chiefdom Headquarter GPS X coordinate (GIS)";
		label var hq_y "Chiefdom Headquarter GPS Y coordinate (GIS)";
		
	*** Drop Bonthe Town;
		drop if ch_code_04cen == 3291;
	
	*** Save file, then work from this analysis in the rest of the data;
		drop ch_nm_trc ch_nm_npwj *_04slihs *_04slihs_2 *_85cen *_slis *_03pets *_02pets *_trc *_mics ch_code ch_nm_gis;
		order ch_nm_04cen ch_code_04cen ch_code_gis district c_index n_atbt hq_x hq_y kill_com maim_com kill_hh maim_hh refugee_hh n_ruf_base target_chief;
		sort ch_code_04cen;
		save "$data/cp_ch_analysis", replace;

	*** WE ARE DONE! =) ***

