#delimit;
clear;
set mem 50m;
capture log close;
capture program drop _all;
set more off;
set logtype text;
set matsize 100;
pause off; 


/*CHANGE THIS LINE TO REFLECT LOCAL DIRECTORY STRUCTURE*/
global REPDIR "C:\Users\ecascardi\Desktop\Data revised";


do "$REPDIR\Replication_WLCA\do_files\directory_location";

*--------------------------------------------------------------------;
* 1) Construct the latest Data for all the data we use;
* 	Then, save temp files "$CP_data/cp_NAME_analysis" that will be;
*	in each table;
*--------------------------------------------------------------------;

	*** Call the latest version of the chiefdom-level data construction file;
		 qui do "$REPDIR\Replication_WLCA\do_files\data_construct";

#d;
*////////////////////////////////////////////////////////////////////////////////////;
log using "$logs/cp_t1", replace;
				****************************************
				******                            ******
				****** Table 1: Descriptive Stats ******
				******                            ******
				****************************************;
*-------------------------------------------;
* Section 1, Column (1): IRCBP Pooled Data 2005 & 2007;
*-------------------------------------------;

use "$data/cp_nps-0507_append_analysis", clear;

	*Panel A: Conflict Victimization;
	tabstat 
		kill_hh maim_hh refugee_hh i_c_index,
		s(mean sd count) column(statistics) format(%9.2f);

	* Panel B: Local Institutions, Politics;
	tabstat 
		mtg_attend_any 
		g_social g_political g_school 
		rvote_all road_brush election_date name_lc name_chief,
		s(mean sd count) column(statistics) format(%9.2f);

	* Panel C: Social Capital;
	tabstat t_comm t_outsider g_church,
		s(mean sd count) column(statistics) format(%9.2f);	

	* Panel D:  SES Outcomes;
	tabstat stove radio roof_tin,
		s(mean sd count) column(statistics) format(%9.2f) ;

	* Panel E:  Respondent Controls;
	tabstat female age educ_any trad_leader,
		s(mean sd count) column(statistics) format(%9.2f) ;

	* Panel F:  1990 Household Controls;
	tabstat *_90,
		s(mean sd count) column(statistics) format(%9.2f) ;
	count;

*-------------------------------------------;
* Section 1, Column (2): GoBifo Sample 2005;
*-------------------------------------------;

use "$data/cp_gbf_analysis", clear;

	*Panel A: Conflict Victimization;
	tabstat 
		kill_hh maim_hh flee_hh child_cap women_cap house_burn i_c_index,
		s(mean sd count) column(statistics) format(%9.2f);

	* Panel B: Local Institutions, Politics;
	tabstat 
		mtg_attend 
		g_pta_smc g_social vote_all
		road_brush election_date name_lc name_chief,
		s(mean sd count) column(statistics) format(%9.2f);

	* Panel C: Social Capital;
	tabstat t_index g_church,
		s(mean sd count) column(statistics) format(%9.2f);	

	* Panel D:  SES Outcomes;
	tabstat stove radio roof_tin,
		s(mean sd count) column(statistics) format(%9.2f) ;

	* Panel E:  Respondent Controls;
	tabstat female age educ_any chief_family,
		s(mean sd count) column(statistics) format(%9.2f) ;
	count;

*-------------------------------------------;
* Chiefdom-Level Data;
*-------------------------------------------;

	use "$data/cp_ch_analysis", clear;

	* Panel F: Conflict Measures;
	tabstat 
		c_index n_atbt,
		s(mean sd count) column(statistics) format(%9.2f);

	* Panel G: Postwar SES Outcomes;
	tabstat 
		lpce_04 enroll_04 bmi_child,
		s(mean sd count) column(statistics) format(%9.2f);

	* Panel H: Postwar Local Public Goods;
	tabstat teach_absent schreceive_comm schreceive_NGO schvisit_chief
		educ_any ngo_tot,
		s(mean sd count) column(statistics) format(%9.2f);

	* Panel I: Prewar Socio-Economic Controls and Geographic Controls;
	tabstat 
		lpce_89 enroll_89 diamonds roaddensity ldistance
		lpop_dens_85 ,
		s(mean sd count) column(statistics) format(%9.2f) ;
log close;
pause "";

#d;
*//////////////////////////////////////////////////////////////////////////////////;
log using "$logs/cp_t2", replace;
				**************************************************
				******                                      ******
				******    Table 2: HH corr. with Conflict   ******
				******                                      ******
				**************************************************;


	* 1) Pooled IRCBP 2005 & 2007;
		use "$data/cp_nps-0507_append_analysis", clear;
		xtset ea_year;
		qui xtreg  i_c_index female age_dm  educ_any trad_leader, 
			robust fe cluster(ea_year);
		estimates store conflict_1;
		test female age_dm educ_any ;

	* 2) IRCBP 2007, with controls;
		use "$data/cp_nps-0507_append_analysis", clear;
		xtset ea_year;
		qui xtreg i_c_index female age_dm educ_any trad_leader head_educ_any_90 hh_trad_leader_90 hh_comm_leader_90, 
			robust fe cluster(ea_year);
		estimates store conflict_2;
		test female age_dm educ_any ;
	
	
	estimates table conflict_1 conflict_2 , stats(N r2 df_a) stf(%9.4g) b(%9.4f) se(%9.4f)  p(%9.4f);
		* All OLS regressions
		* Robust Standard errors reported below coefficients, clustered at village/EA level
		* p-values for two-sided t-test reported below that;
	estimates clear;
log close;
pause "";

#d;
*////////////////////////////////////////////////////////////////////////////////////;
log using "$logs/cp_t3", replace;
				**************************************************
				******                                      ******
				******    Table 3: Meetings with Conflict   ******
				******                                      ******
				**************************************************;
#d;
	* 1) Pooled IRCBP 2005 & 2007, no controls;
		use "$data/cp_nps-0507_append_analysis", clear;
		xtset ea_year;
		qui xtreg mtg_attend_any i_c_index , 
			robust fe cluster(ea_year); /* same sample that with controls */
		qui xtreg mtg_attend_any i_c_index if e(sample)==1, 
			robust fe cluster(ea_year);
		estimates store mtg_1;
	* 2) Pooled IRCBP 2005 & 2007, controls;
		use "$data/cp_nps-0507_append_analysis", clear;
		xtset ea_year;
		qui xtreg mtg_attend_any i_c_index female age_dm  educ_any trad_leader, 
			robust fe cluster(ea_year);
		estimates store mtg_2;
	* 3) IRCBP 2007, no controls;
		use "$data/cp_nps-0507_append_analysis", clear;
		xtset ea_year;
		qui xtreg mtg_attend_any i_c_index if year == 2007, 
			robust fe cluster(ea_year);
		estimates store mtg_3;
	* 4) IRCBP 2007, controls;
		use "$data/cp_nps-0507_append_analysis", clear;
		xtset ea_year;
		qui xtreg mtg_attend_any i_c_index female age_dm educ_any trad_leader head_educ_any_90 hh_trad_leader_90 hh_comm_leader_90, 
			robust fe cluster(ea_year);
		estimates store mtg_4;
		
	estimates table mtg_1 mtg_2 mtg_3 mtg_4, stats(N r2 df_a) stf(%9.4g) b(%9.4f) se(%9.4f)  p(%9.4f);
		* All OLS regressions
		* Robust Standard errors reported below coefficients, clustered at village/EA level
		* p-values for two-sided t-test reported below that;
	estimates clear;
log close;
pause "";

*///////////////////////////////////////////////////////////////////////////////////;
log using "$logs/cp_t4", replace;

				****************************************************
				******                                        ******
				******    Table 4: Social Group with Conflict ******
				******                                        ******
				**************************************************;

	* 1) Pooled IRCBP 2005 & 2007, no controls;
		use "$data/cp_nps-0507_append_analysis", clear;
		xtset ea_year;
		qui xtreg g_social i_c_index female age_dm  educ_any trad_leader, 
			robust fe cluster(ea_year); /* same sample that with controls */
		qui xtreg g_social i_c_index if e(sample)==1, 
			robust fe cluster(ea_year);
		estimates store soc_1;
	* 2) Pooled IRCBP 2005 & 2007, controls;
		use "$data/cp_nps-0507_append_analysis", clear;
		xtset ea_year;
		qui xtreg g_social i_c_index female age_dm  educ_any trad_leader, 
			robust fe cluster(ea_year);
		estimates store soc_2;
	* 3) IRCBP 2007, no controls;
		use "$data/cp_nps-0507_append_analysis", clear;
		xtset ea_year;
		qui xtreg g_social i_c_index if year == 2007, 
			robust fe cluster(ea_year);
		estimates store soc_3;
	* 4) IRCBP 2007, with 1990 controls;
		use "$data/cp_nps-0507_append_analysis", clear;
		xtset ea_year;
		qui xtreg g_social i_c_index female age_dm  educ_any trad_leader head_educ_any_90 hh_trad_leader_90 hh_comm_leader_90, 
			robust fe cluster(ea_year);
		estimates store soc_4;
		
	estimates table soc_1 soc_2 soc_3 soc_4, stats(N r2 df_a) stf(%9.4g) b(%9.4f) se(%9.4f)  p(%9.4f);
		* All OLS regressions
		* Robust Standard errors reported below coefficients, clustered at village/EA level
		* p-values for two-sided t-test reported below that;
	estimates clear;

log close;
pause "";

*//////////////////////////////////////////////////////////////////////////////;
log using "$logs/cp_t5", replace;

				*******************************************************
				******                                           ******
				******    Table 5: Political Group with Conflict ******
				******                                           ******
				*******************************************************;

	* 1) Pooled IRCBP 2005 & 2007, no controls;
		use "$data/cp_nps-0507_append_analysis", clear;
		xtset ea_year;
		qui xtreg g_political i_c_index female age_dm  educ_any trad_leader, 
			robust fe cluster(ea_year); /* same sample that with controls */
		qui xtreg g_political i_c_index if e(sample)==1, 
			robust fe cluster(ea_year);
		estimates store pol_1;
	* 2) Pooled IRCBP 2005 & 2007, controls;
		use "$data/cp_nps-0507_append_analysis", clear;
		xtset ea_year;
		qui xtreg g_political i_c_index female age_dm  educ_any trad_leader, 
			robust fe cluster(ea_year);
		estimates store pol_2;
	* 3) IRCBP 2007, no controls;
		use "$data/cp_nps-0507_append_analysis", clear;
		xtset ea_year;
		qui xtreg g_political i_c_index if year == 2007, 
			robust fe cluster(ea_year);
		estimates store pol_3;
	* 4) IRCBP 2007, with 1990 controls;
		use "$data/cp_nps-0507_append_analysis", clear;
		xtset ea_year;
		qui xtreg g_political i_c_index female age_dm  educ_any trad_leader head_educ_any_90 hh_trad_leader_90 hh_comm_leader_90, 
			robust fe cluster(ea_year);
		estimates store pol_4;

	estimates table pol_1 pol_2 pol_3 pol_4, stats(N r2 df_a) stf(%9.4g) b(%9.4f) se(%9.4f)  p(%9.4f);
		* All OLS regressions
		* Robust Standard errors reported below coefficients, clustered at village/EA level
		* p-values for two-sided t-test reported below that;
	estimates clear;

log close;
pause "";

#d;
*////////////////////////////////////////////////////////////////////////////////////;
log using "$logs/cp_t6_nonmigrate", replace;

				**************************************************
				******                                      ******
				******    Table 6: Various Outcomes with Conflict   ******
				******                                      ******
				**************************************************;
#d;
	/* Need to put in the No RUF bases chiefdom in order to run column (3) */;

		use "$data/cp_nps-0507_append_analysis", clear;
	
		* Need to merge in the NPWJ data;
			destring(ch_code), replace;
			gen ch_code_04cen = ch_code;
			sort ch_code_04cen;
			merge ch_code_04cen using "$temp/npwj_c";
			keep if _merge == 3;	/* Drops Bonthe town and the one Ch not sampled in IRCBP */;
		* For column (3), include the following if statement: if n_ruf_base == 0;
			save "$data/cp_nps-npwj_analysis", replace;

*-----------------------------------------------------;	
* Panel A: Mobilization, Voting, and Group Memberships;
*-----------------------------------------------------;

	* 1. Community Meetings;
		* A. IRCBP Pooled;
		use "$data/cp_nps-npwj_analysis", clear;
		xtset ea_year;
		qui xtreg mtg_attend_any i_c_index female age_dm educ_any trad_leader, robust fe cluster(ea_year);
		estimates store c_1;
		* B. IRCBP Under 30;
		use "$data/cp_nps-npwj_analysis", clear;
		xtset ea_year;
		gen age_05 = age;
		replace age_05 = age - 2 if year == 2007;
		qui xtreg mtg_attend_any i_c_index female age_dm educ_any trad_leader if age_05 <= 30, robust fe cluster(ea_year);
		estimates store c_2;
		* C. IRCBP, No RUF bases;
		use "$data/cp_nps-npwj_analysis", clear;
		xtset ea_year;
		qui xtreg mtg_attend_any i_c_index female age_dm educ_any trad_leader if n_ruf_base == 0, robust fe cluster(ea_year);
		estimates store c_3;
		* D. GoBifo;
		use "$data/cp_gbf_analysis", clear;
		xtset id_vill;
		qui xtreg mtg_attend i_c_index female age_dm educ_any chief_family, robust fe cluster(id_vill);
		estimates store c_4;
	
		* Show the estimates;
		estimates table c_1 c_2 c_3 c_4, stats(N r2 df_a) stf(%9.4g) b(%9.4f) se(%9.4f)  p(%9.4f);
		estimates clear;

	* 2. Social Group;
		* A. IRCBP Pooled;
		use "$data/cp_nps-npwj_analysis", clear;
		xtset ea_year;
		qui xtreg g_social i_c_index female age_dm educ_any trad_leader, robust fe cluster(ea_year);
		estimates store c_1;
		* B. IRCBP Under 30;
		use "$data/cp_nps-npwj_analysis", clear;
		xtset ea_year;
		gen age_05 = age;
		replace age_05 = age - 2 if year == 2007;
		qui xtreg g_social i_c_index female age_dm educ_any trad_leader if age_05 <= 30, robust fe cluster(ea_year);
		estimates store c_2;
		* C. IRCBP, No RUF bases;
		use "$data/cp_nps-npwj_analysis", clear;
		xtset ea_year;
		qui xtreg g_social i_c_index female age_dm educ_any trad_leader if n_ruf_base == 0, robust fe cluster(ea_year);
		estimates store c_3;
		* D. GoBifo;
		use "$data/cp_gbf_analysis", clear;
		xtset id_vill;
		qui xtreg g_social i_c_index female age_dm educ_any chief_family, robust fe cluster(id_vill);
		estimates store c_4;
	
		* Show the estimates;
		estimates table c_1 c_2 c_3 c_4, stats(N r2 df_a) stf(%9.4g) b(%9.4f) se(%9.4f)  p(%9.4f);
		estimates clear;


	* 3. Political Group;
		* A. IRCBP Pooled;
		use "$data/cp_nps-npwj_analysis", clear;
		xtset ea_year;
		qui xtreg g_political i_c_index female age_dm educ_any trad_leader, robust fe cluster(ea_year);
		estimates store c_1;
		* B. IRCBP Under 30;
		use "$data/cp_nps-npwj_analysis", clear;
		xtset ea_year;
		gen age_05 = age;
		replace age_05 = age - 2 if year == 2007;
		qui xtreg g_political i_c_index female age_dm educ_any trad_leader if age_05 <= 30, robust fe cluster(ea_year);
		estimates store c_2;
		* C. IRCBP, No RUF bases;
		use "$data/cp_nps-npwj_analysis", clear;
		xtset ea_year;
		qui xtreg g_political i_c_index female age_dm educ_any trad_leader if n_ruf_base == 0, robust fe cluster(ea_year);
		estimates store c_3;
	
		* Show the estimates;
		estimates table c_1 c_2 c_3, stats(N r2 df_a) stf(%9.4g) b(%9.4f) se(%9.4f)  p(%9.4f);
		estimates clear;
pause "";

	* 4. SMC;
		* A. IRCBP Pooled;
		use "$data/cp_nps-npwj_analysis", clear;
		xtset ea_year;
		qui xtreg g_school i_c_index female age_dm educ_any trad_leader, robust fe cluster(ea_year);
		estimates store c_1;
		* B. IRCBP Under 30;
		use "$data/cp_nps-npwj_analysis", clear;
		xtset ea_year;
		gen age_05 = age;
		replace age_05 = age - 2 if year == 2007;
		qui xtreg g_school i_c_index female age_dm educ_any trad_leader if age_05 <= 30, robust fe cluster(ea_year);
		estimates store c_2;
		* C. IRCBP, No RUF bases;
		use "$data/cp_nps-npwj_analysis", clear;
		xtset ea_year;
		qui xtreg g_school i_c_index female age_dm educ_any trad_leader if n_ruf_base == 0, robust fe cluster(ea_year);
		estimates store c_3;
		* D. GoBifo;
		use "$data/cp_gbf_analysis", clear;
		xtset id_vill;
		qui xtreg g_pta_smc i_c_index female age_dm educ_any chief_family, robust fe cluster(id_vill);
		estimates store c_4;
	
		* Show the estimates;
		estimates table c_1 c_2 c_3 c_4, stats(N r2 df_a) stf(%9.4g) b(%9.4f) se(%9.4f)  p(%9.4f);
		estimates clear;

	* 5. Vote;
		* A. IRCBP Pooled;
		use "$data/cp_nps-npwj_analysis", clear;
		xtset ea_year;
		qui xtreg rvote_all i_c_index female age_dm educ_any trad_leader if year == 2005, robust fe cluster(ea_year);
		estimates store c_1;
		* B. IRCBP Under 30;
		use "$data/cp_nps-npwj_analysis", clear;
		xtset ea_year;
		gen age_05 = age;
		replace age_05 = age - 2 if year == 2007;
		qui xtreg rvote_all i_c_index female age_dm educ_any trad_leader if age_05 <= 30 & year == 2005, robust fe cluster(ea_year);
		estimates store c_2;
		* C. IRCBP, No RUF bases;
		use "$data/cp_nps-npwj_analysis", clear;
		xtset ea_year;
		qui xtreg rvote_all i_c_index female age_dm educ_any trad_leader if n_ruf_base == 0 & year == 2005, robust fe cluster(ea_year);
		estimates store c_3;
		* D. GoBifo;
		use "$data/cp_gbf_analysis", clear;
		xtset id_vill;
		qui xtreg vote_all i_c_index female age_dm educ_any chief_family, robust fe cluster(id_vill);
		estimates store c_4;
	
		* Show the estimates;
		estimates table c_1 c_2 c_3 c_4, stats(N r2 df_a) stf(%9.4g) b(%9.4f) se(%9.4f)  p(%9.4f);
		estimates clear;


	* 6. Road Brushing;
		* A. IRCBP Pooled;
		use "$data/cp_nps-npwj_analysis", clear;
		xtset ea_year;
		qui xtreg road_brush i_c_index female age_dm educ_any trad_leader, robust fe cluster(ea_year);
		estimates store c_1;
		* B. IRCBP Under 30;
		use "$data/cp_nps-npwj_analysis", clear;
		xtset ea_year;
		gen age_05 = age;
		replace age_05 = age - 2 if year == 2007;
		qui xtreg road_brush i_c_index female age_dm educ_any trad_leader if age_05 <= 30, robust fe cluster(ea_year);
		estimates store c_2;
		* C. IRCBP, No RUF bases;
		use "$data/cp_nps-npwj_analysis", clear;
		xtset ea_year;
		qui xtreg road_brush i_c_index female age_dm educ_any trad_leader if n_ruf_base == 0, robust fe cluster(ea_year);
		estimates store c_3;
		* D. GoBifo;
		use "$data/cp_gbf_analysis", clear;
		xtset id_vill;
		qui xtreg road_brush i_c_index female age_dm educ_any chief_family, robust fe cluster(id_vill);
		estimates store c_4;
	
		* Show the estimates;
		estimates table c_1 c_2 c_3 c_4, stats(N r2 df_a) stf(%9.4g) b(%9.4f) se(%9.4f)  p(%9.4f);
		estimates clear;
pause "";

*-----------------------------------------------------;	
* Panel B: Political Knowledge;
*-----------------------------------------------------;
#d;
	* 7. Next Election;
		* A. IRCBP Pooled;
		use "$data/cp_nps-npwj_analysis", clear;
		xtset ea_year;
		qui xtreg election_date i_c_index female age_dm educ_any trad_leader, robust fe cluster(ea_year);
		estimates store c_1;
		* B. IRCBP Under 30;
		use "$data/cp_nps-npwj_analysis", clear;
		xtset ea_year;
		gen age_05 = age;
		replace age_05 = age - 2 if year == 2007;
		qui xtreg election_date i_c_index female age_dm educ_any trad_leader if age_05 <= 30, robust fe cluster(ea_year);
		estimates store c_2;
		* C. IRCBP, No RUF bases;
		use "$data/cp_nps-npwj_analysis", clear;
		xtset ea_year;
		qui xtreg election_date i_c_index female age_dm educ_any trad_leader if n_ruf_base == 0, robust fe cluster(ea_year);
		estimates store c_3;
		* D. GoBifo;
		use "$data/cp_gbf_analysis", clear;
		xtset id_vill;
		qui xtreg election_date i_c_index female age_dm educ_any chief_family, robust fe cluster(id_vill);
		estimates store c_4;
	
		* Show the estimates;
		estimates table c_1 c_2 c_3 c_4, stats(N r2 df_a) stf(%9.4g) b(%9.4f) se(%9.4f)  p(%9.4f);
		estimates clear;

	* 8. Name LC;
		* A. IRCBP Pooled;
		use "$data/cp_nps-npwj_analysis", clear;
		xtset ea_year;
		qui xtreg name_lc i_c_index female age_dm educ_any trad_leader, robust fe cluster(ea_year);
		estimates store c_1;
		* B. IRCBP Under 30;
		use "$data/cp_nps-npwj_analysis", clear;
		xtset ea_year;
		gen age_05 = age;
		replace age_05 = age - 2 if year == 2007;
		qui xtreg name_lc i_c_index female age_dm educ_any trad_leader if age_05 <= 30, robust fe cluster(ea_year);
		estimates store c_2;
		* C. IRCBP, No RUF bases;
		use "$data/cp_nps-npwj_analysis", clear;
		xtset ea_year;
		qui xtreg name_lc i_c_index female age_dm educ_any trad_leader if n_ruf_base == 0, robust fe cluster(ea_year);
		estimates store c_3;
		* D. GoBifo;
		use "$data/cp_gbf_analysis", clear;
		xtset id_vill;
		qui xtreg name_lc i_c_index female age_dm educ_any chief_family, robust fe cluster(id_vill);
		estimates store c_4;
	
		* Show the estimates;
		estimates table c_1 c_2 c_3 c_4, stats(N r2 df_a) stf(%9.4g) b(%9.4f) se(%9.4f)  p(%9.4f);
		estimates clear;

	* 9. Name Chief;
		* A. IRCBP Pooled;
		use "$data/cp_nps-npwj_analysis", clear;
		xtset ea_year;
		qui xtreg name_chief i_c_index female age_dm educ_any trad_leader, robust fe cluster(ea_year);
		estimates store c_1;
		* B. IRCBP Under 30;
		use "$data/cp_nps-npwj_analysis", clear;
		xtset ea_year;
		gen age_05 = age;
		replace age_05 = age - 2 if year == 2007;
		qui xtreg name_chief i_c_index female age_dm educ_any trad_leader if age_05 <= 30, robust fe cluster(ea_year);
		estimates store c_2;
		* C. IRCBP, No RUF bases;
		use "$data/cp_nps-npwj_analysis", clear;
		xtset ea_year;
		qui xtreg name_chief i_c_index female age_dm educ_any trad_leader if n_ruf_base == 0, robust fe cluster(ea_year);
		estimates store c_3;
		* D. GoBifo;
		use "$data/cp_gbf_analysis", clear;
		xtset id_vill;
		qui xtreg name_chief i_c_index female age_dm educ_any chief_family, robust fe cluster(id_vill);
		estimates store c_4;
	
		* Show the estimates;
		estimates table c_1 c_2 c_3 c_4, stats(N r2 df_a) stf(%9.4g) b(%9.4f) se(%9.4f)  p(%9.4f);
		estimates clear;

pause "";

*-----------------------------------------------------;	
* Panel C: Trust and Religion;
*-----------------------------------------------------;
#d;

	* 10. Trust Outsiders;
		* A. IRCBP Pooled;
		use "$data/cp_nps-npwj_analysis", clear;
		xtset ea_year;
		qui xtreg t_outsider i_c_index female age_dm educ_any trad_leader, robust fe cluster(ea_year);
		estimates store c_1;
		* B. IRCBP Under 30;
		use "$data/cp_nps-npwj_analysis", clear;
		xtset ea_year;
		gen age_05 = age;
		replace age_05 = age - 2 if year == 2007;
		qui xtreg t_outsider i_c_index female age_dm educ_any trad_leader if age_05 <= 30, robust fe cluster(ea_year);
		estimates store c_2;
		* C. IRCBP, No RUF bases;
		use "$data/cp_nps-npwj_analysis", clear;
		xtset ea_year;
		qui xtreg t_outsider i_c_index female age_dm educ_any trad_leader if n_ruf_base == 0, robust fe cluster(ea_year);
		estimates store c_3;
	
		* Show the estimates;
		estimates table c_1 c_2 c_3, stats(N r2 df_a) stf(%9.4g) b(%9.4f) se(%9.4f)  p(%9.4f);
		estimates clear;

	* 11. Trust Community;
		* A. IRCBP Pooled;
		use "$data/cp_nps-npwj_analysis", clear;
		xtset ea_year;
		qui xtreg t_comm i_c_index female age_dm educ_any trad_leader, robust fe cluster(ea_year);
		estimates store c_1;
		* B. IRCBP Under 30;
		use "$data/cp_nps-npwj_analysis", clear;
		xtset ea_year;
		gen age_05 = age;
		replace age_05 = age - 2 if year == 2007;
		qui xtreg t_comm i_c_index female age_dm educ_any trad_leader if age_05 <= 30, robust fe cluster(ea_year);
		estimates store c_2;
		* C. IRCBP, No RUF bases;
		use "$data/cp_nps-npwj_analysis", clear;
		xtset ea_year;
		qui xtreg t_comm i_c_index female age_dm educ_any trad_leader if n_ruf_base == 0, robust fe cluster(ea_year);
		estimates store c_3;
		* D. GoBifo;
		use "$data/cp_gbf_analysis", clear;
		xtset id_vill;
		qui xtreg t_index i_c_index female age_dm educ_any chief_family, robust fe cluster(id_vill);
		estimates store c_4;
	
		* Show the estimates;
		estimates table c_1 c_2 c_3 c_4, stats(N r2 df_a) stf(%9.4g) b(%9.4f) se(%9.4f)  p(%9.4f);
		estimates clear;

	* 12. Church;
		* A. IRCBP Pooled;
		use "$data/cp_nps-npwj_analysis", clear;
		xtset ea_year;
		qui xtreg g_church i_c_index female age_dm educ_any trad_leader, robust fe cluster(ea_year);
		estimates store c_1;
		* B. IRCBP Under 30;
		use "$data/cp_nps-npwj_analysis", clear;
		xtset ea_year;
		gen age_05 = age;
		replace age_05 = age - 2 if year == 2007;
		qui xtreg g_church i_c_index female age_dm educ_any trad_leader if age_05 <= 30, robust fe cluster(ea_year);
		estimates store c_2;
		* C. IRCBP, No RUF bases;
		use "$data/cp_nps-npwj_analysis", clear;
		xtset ea_year;
		qui xtreg g_church i_c_index female age_dm educ_any trad_leader if n_ruf_base == 0, robust fe cluster(ea_year);
		estimates store c_3;
		* D. GoBifo;
		use "$data/cp_gbf_analysis", clear;
		xtset id_vill;
		qui xtreg g_church i_c_index female age_dm educ_any chief_family, robust fe cluster(id_vill);
		estimates store c_4;
	
		* Show the estimates;
		estimates table c_1 c_2 c_3 c_4, stats(N r2 df_a) stf(%9.4g) b(%9.4f) se(%9.4f)  p(%9.4f);
		estimates clear;
#d;
*-------------------------------------------;	
* Panel D: Socio-Economic Outcomes;
*-------------------------------------------;

	* 13. Stove;
		* A. IRCBP Pooled;
		use "$data/cp_nps-npwj_analysis", clear;
		xtset ea_year;
		qui xtreg stove i_c_index female age_dm educ_any trad_leader, robust fe cluster(ea_year);
		estimates store c_1;
		* B. IRCBP Under 30;
		use "$data/cp_nps-npwj_analysis", clear;
		xtset ea_year;
		gen age_05 = age;
		replace age_05 = age - 2 if year == 2007;
		qui xtreg stove i_c_index female age_dm educ_any trad_leader if age_05 <= 30, robust fe cluster(ea_year);
		estimates store c_2;
		* C. IRCBP, No RUF bases;
		use "$data/cp_nps-npwj_analysis", clear;
		xtset ea_year;
		qui xtreg stove i_c_index female age_dm educ_any trad_leader if n_ruf_base == 0, robust fe cluster(ea_year);
		estimates store c_3;
		* D. GoBifo;
		use "$data/cp_gbf_analysis", clear;
		xtset id_vill;
		qui xtreg stove i_c_index female age_dm educ_any chief_family, robust fe cluster(id_vill);
		estimates store c_4;
	
		* Show the estimates;
		estimates table c_1 c_2 c_3 c_4, stats(N r2 df_a) stf(%9.4g) b(%9.4f) se(%9.4f)  p(%9.4f);
		estimates clear;

	* 14. Radio;
		* A. IRCBP Pooled;
		use "$data/cp_nps-npwj_analysis", clear;
		xtset ea_year;
		qui xtreg radio i_c_index female age_dm educ_any trad_leader, robust fe cluster(ea_year);
		estimates store c_1;
		* B. IRCBP Under 30;
		use "$data/cp_nps-npwj_analysis", clear;
		xtset ea_year;
		gen age_05 = age;
		replace age_05 = age - 2 if year == 2007;
		qui xtreg radio i_c_index female age_dm educ_any trad_leader if age_05 <= 30, robust fe cluster(ea_year);
		estimates store c_2;
		* C. IRCBP, No RUF bases;
		use "$data/cp_nps-npwj_analysis", clear;
		xtset ea_year;
		qui xtreg radio i_c_index female age_dm educ_any trad_leader if n_ruf_base == 0, robust fe cluster(ea_year);
		estimates store c_3;
		* D. GoBifo;
		use "$data/cp_gbf_analysis", clear;
		xtset id_vill;
		qui xtreg radio i_c_index female age_dm educ_any chief_family, robust fe cluster(id_vill);
		estimates store c_4;
	
		* Show the estimates;
		estimates table c_1 c_2 c_3 c_4, stats(N r2 df_a) stf(%9.4g) b(%9.4f) se(%9.4f)  p(%9.4f);
		estimates clear;

	* 15. Roof;
		* A. IRCBP Pooled;
		use "$data/cp_nps-npwj_analysis", clear;
		xtset ea_year;
		qui xtreg roof i_c_index female age_dm educ_any trad_leader, robust fe cluster(ea_year);
		estimates store c_1;
		* B. IRCBP Under 30;
		use "$data/cp_nps-npwj_analysis", clear;
		xtset ea_year;
		gen age_05 = age;
		replace age_05 = age - 2 if year == 2007;
		qui xtreg roof i_c_index female age_dm educ_any trad_leader if age_05 <= 30, robust fe cluster(ea_year);
		estimates store c_2;
		* C. IRCBP, No RUF bases;
		use "$data/cp_nps-npwj_analysis", clear;
		xtset ea_year;
		qui xtreg roof i_c_index female age_dm educ_any trad_leader if n_ruf_base == 0, robust fe cluster(ea_year);
		estimates store c_3;
		* D. GoBifo;
		use "$data/cp_gbf_analysis", clear;
		xtset id_vill;
		qui xtreg roof i_c_index female age_dm educ_any chief_family, robust fe cluster(id_vill);
		estimates store c_4;
	
		* Show the estimates;
		estimates table c_1 c_2 c_3 c_4, stats(N r2 df_a) stf(%9.4g) b(%9.4f) se(%9.4f)  p(%9.4f);
		estimates clear;
pause "";		

pause "";
log close;

#d;
*///////////////////////////////////////////////////////////////////////;
log using "$logs/cp_t7", replace;
				******************************************
				******                              ******
				******    Table 7: Ch Selection     ******
				******                              ******
				******************************************;

use "$data/cp_ch_analysis", clear;

	* Locals for the Chiefdom level regs
		local ch_conflict "c_index n_atbt";
		local ch_geo "diamonds roaddensity ldistance  ";
		local ch_pop "lpop_dens_85";
		local ch_control_04 "educ_any_04 ngo_tot";
		local ch_hh89 "enroll_89 lpce_89";
		local ch_dia_inter "dia_sch dia_ftown dia_expend dia_road";
		local ch_control_other "nondiamonds riverdensity";

*-------------------------------------------------------;
* Columns (1)-(3), Dependent variable: attacks & battles;
*--------------------------------------------------------;

	qui reg n_atbt `ch_geo' `ch_pop' `ch_control_other', robust cluster(district);
	estimates store conflict_1;
	sort district;
	egen id_district = group(district);
	xtset id_district;
	qui xtreg n_atbt `ch_geo' `ch_pop' `ch_control_other', robust fe cluster(district);
	estimates store conflict_2;
	qui xtreg n_atbt `ch_geo' `ch_pop' `ch_hh89' `ch_control_other', robust fe cluster(district);
	estimates store conflict_3;

	estimates table conflict_1 conflict_2 conflict_3 , stats(N r2) b(%9.4f) se(%9.4f)  p(%9.4f);
		* All OLS regressions
		* Robust Standard errors reported below coefficients, clustered at District level
		* p-values for two-sided t-test reported below that;
	estimates clear;

*----------------------------------------------------;
* Columns (4)-(6), Dependent variable: conflict index;
*----------------------------------------------------;

	qui reg c_index `ch_geo' `ch_pop' `ch_control_other', robust cluster(district);
	estimates store conflict_1;
	qui xtreg c_index `ch_geo' `ch_pop' `ch_control_other', robust fe cluster(district);
	estimates store conflict_2;
	qui xtreg c_index `ch_geo' `ch_pop'  `ch_hh89' `ch_control_other', robust fe cluster(district);
	estimates store conflict_3;

	estimates table conflict_1 conflict_2 conflict_3 , stats(N r2) b(%9.4f) se(%9.4f)  p(%9.4f);
		* All OLS regressions
		* Robust Standard errors reported below coefficients, clustered at District level
		* p-values for two-sided t-test reported below that;
	estimates clear;

log close;
pause "";



*///////////////////////////////////////////////////////////////////////;
log using "$logs/cp_t8", replace;
				******************************************
				******                              ******
				******    Table 8: LPC Expenditure  ******
				******                              ******
				******************************************;


use "$data/cp_ch_analysis", clear;

	* Locals for the Chiefdom level regs
		local ch_conflict "c_index n_atbt";
		local ch_geo "diamonds roaddensity ldistance  ";
		local ch_pop "lpop_dens_85";
		local ch_control_04 "educ_any_04 ngo_tot";
		local ch_hh89 "enroll_89 lpce_89";
		local ch_dia_inter "dia_sch dia_ftown dia_expend dia_road";
		local ch_control_other "nondiamonds riverdensity";

	qui reg lpce_04 c_index n_atbt `ch_geo' `ch_pop' `ch_control_other', robust cluster(district); 
	estimates store lpce_1;
	sort district;
	egen id_district = group(district);
	xtset id_district;
	qui xtreg lpce_04 c_index n_atbt `ch_geo' `ch_pop' `ch_control_other', robust fe cluster(district); 
	estimates store lpce_2;
	qui xtreg lpce_04 c_index n_atbt `ch_geo' `ch_pop' `ch_control_other' `ch_hh89', robust fe cluster(district); 
	estimates store lpce_3;

	estimates table lpce_1 lpce_2 lpce_3, stats(N r2 df_a) b(%9.4f) se(%9.4f) p(%9.4f);
		* All OLS regressions
		* Robust Standard errors reported below coefficients, clustered at District level
		* p-values for two-sided t-test reported below that;
	estimates clear;


log close;
#d;
*////////////////////////////////////////////////////////////////////////////;
log using "$logs/cp_t9", replace;
				******************************************
				******                              ******
				******  Table 9: CH SES & CONFLICT  ******
				******                              ******
				******************************************;


use "$data/cp_ch_analysis", clear;
sort district;
egen id_district = group(district);
xtset id_district;

	* Locals for the Chiefdom level regs
		local ch_conflict "c_index n_atbt";
		local ch_geo "diamonds roaddensity ldistance  ";
		local ch_pop "lpop_dens_85";
		local ch_control_04 "educ_any_04 ngo_tot";
		local ch_hh89 "enroll_89 lpce_89";
		local ch_dia_inter "dia_sch dia_ftown dia_expend dia_road";
		local ch_control_other "nondiamonds riverdensity";

	foreach var of varlist lpce_04 enroll_04 bmi_child teach_absent schreceive_comm schreceive_NGO schvisit_chief educ_any ngo_tot{;
		qui xtreg `var' c_index n_atbt `ch_geo' `ch_pop' `ch_control_other', robust fe cluster(district); 
		estimates store e_`var';
	};

	*-------------------------------------------;	
	* Panel A: Socio-Economic Outcomes;
	*-------------------------------------------;	
	estimates table e_lpce_04 e_enroll_04 e_bmi_child_04 
			, stats(N r2 df_a) b(%9.4f) se(%9.4f) p(%9.4f);

	*-------------------------------------------;	
	* Panel B: Local Public Goods;
	*-------------------------------------------;
	estimates table e_teach_absent e_schreceive_comm e_schreceive_NGO e_schvisit_chief
			, stats(N r2 df_a) b(%9.4f) se(%9.4f) p(%9.4f);

	*-------------------------------------------;	
	* Panel C: Adult Educ and NGO projects in 2004;
	*-------------------------------------------;
	estimates table e_educ_any e_ngo_tot, stats(N r2) b(%9.4f) se(%9.4f) p(%9.4f);
		* All OLS regressions
		* Robust Standard errors reported below coefficients, clustered at village/EA level
		* p-values for two-sided t-test reported below that;
	estimates clear;

log close;
